@@ -1,20 +1,21 @@
 """
 ==================
-Demo Floating Axis
+floating_axis demo
 ==================
 
-Axis within rectangular frame
+Axis within rectangular frame.
 
 The following code demonstrates how to put a floating polar curve within a
 rectangular box. In order to get a better sense of polar curves, please look at
 :doc:`/gallery/axisartist/demo_curvelinear_grid`.
 """
+
 import numpy as np
 import matplotlib.pyplot as plt
 import mpl_toolkits.axisartist.angle_helper as angle_helper
 from matplotlib.projections import PolarAxes
 from matplotlib.transforms import Affine2D
-from mpl_toolkits.axisartist import SubplotHost
+from mpl_toolkits.axisartist import HostAxes
 from mpl_toolkits.axisartist import GridHelperCurveLinear
 
 
@@ -42,9 +43,7 @@ def curvelinear_test2(fig):
                                         tick_formatter1=tick_formatter1
                                         )
 
-    ax1 = SubplotHost(fig, 1, 1, 1, grid_helper=grid_helper)
-
-    fig.add_subplot(ax1)
+    ax1 = fig.add_subplot(axes_class=HostAxes, grid_helper=grid_helper)
 
     # Now creates floating axis
 
