@@ -17,14 +17,9 @@ plt.show()
 
 #############################################################################
 #
-# ------------
+# .. admonition:: References
 #
-# References
-# """"""""""
+#    The use of the following functions, methods, classes and modules is shown
+#    in this example:
 #
-# The use of the following functions and methods is shown
-# in this example:
-
-import matplotlib
-matplotlib.axes.Axes.matshow
-matplotlib.pyplot.matshow
+#    - `matplotlib.axes.Axes.imshow` / `matplotlib.pyplot.imshow`
