@@ -72,15 +72,10 @@ plt.tight_layout()
 plt.show()
 #############################################################################
 #
-# ------------
+# .. admonition:: References
 #
-# References
-# """"""""""
+#    The use of the following functions, methods, classes and modules is shown
+#    in this example:
 #
-# The use of the following functions and methods is shown in this example:
-
-import matplotlib
-matplotlib.axes.Axes.streamplot
-matplotlib.pyplot.streamplot
-matplotlib.gridspec
-matplotlib.gridspec.GridSpec
+#    - `matplotlib.axes.Axes.streamplot` / `matplotlib.pyplot.streamplot`
+#    - `matplotlib.gridspec.GridSpec`
