@@ -9,9 +9,7 @@ a faster generalization of `~.axes.Axes.pcolor`, but with some restrictions.
 This demo illustrates a bug in quadmesh with masked data.
 """
 
-import copy
-
-from matplotlib import cm, pyplot as plt
+from matplotlib import pyplot as plt
 import numpy as np
 
 n = 12
@@ -30,10 +28,8 @@ fig, axs = plt.subplots(nrows=1, ncols=3)
 axs[0].pcolormesh(Qx, Qz, Z, shading='gouraud')
 axs[0].set_title('Without masked values')
 
-# You can control the color of the masked region. We copy the default colormap
-# before modifying it.
-cmap = copy.copy(cm.get_cmap(plt.rcParams['image.cmap']))
-cmap.set_bad('y', 1.0)
+# You can control the color of the masked region.
+cmap = plt.colormaps[plt.rcParams['image.cmap']].with_extremes(bad='y')
 axs[1].pcolormesh(Qx, Qz, Zm, shading='gouraud', cmap=cmap)
 axs[1].set_title('With masked values')
 
@@ -46,13 +42,9 @@ plt.show()
 
 #############################################################################
 #
-# ------------
+# .. admonition:: References
 #
-# References
-# """"""""""
+#    The use of the following functions, methods, classes and modules is shown
+#    in this example:
 #
-# The use of the following functions and methods is shown in this example:
-
-import matplotlib
-matplotlib.axes.Axes.pcolormesh
-matplotlib.pyplot.pcolormesh
+#    - `matplotlib.axes.Axes.pcolormesh` / `matplotlib.pyplot.pcolormesh`
