@@ -55,14 +55,9 @@ plt.show()
 
 ##############################################################################
 #
-# ------------
+# .. admonition:: References
 #
-# References
-# """"""""""
+#    The use of the following functions, methods, classes and modules is shown
+#    in this example:
 #
-# The use of the following functions, methods, classes and modules is shown
-# in this example:
-
-import matplotlib
-matplotlib.axes.Axes.errorbar
-matplotlib.pyplot.errorbar
+#    - `matplotlib.axes.Axes.errorbar` / `matplotlib.pyplot.errorbar`
