@@ -11,12 +11,8 @@ from mpl_toolkits.mplot3d import axes3d
 import matplotlib.pyplot as plt
 from matplotlib import cm
 
-fig = plt.figure()
-ax = fig.gca(projection='3d')
+ax = plt.figure().add_subplot(projection='3d')
 X, Y, Z = axes3d.get_test_data(0.05)
-
-cset = ax.contour(X, Y, Z, extend3d=True, cmap=cm.coolwarm)
-
-ax.clabel(cset, fontsize=9, inline=True)
+ax.contour(X, Y, Z, extend3d=True, cmap=cm.coolwarm)
 
 plt.show()
