@@ -7,20 +7,17 @@ Demonstrates the placement of text annotations on a 3D plot.
 
 Functionality shown:
 
-    - Using the text function with three types of 'zdir' values: None, an axis
-      name (ex. 'x'), or a direction tuple (ex. (1, 1, 0)).
-    - Using the text function with the color keyword.
-
-    - Using the text2D function to place text on a fixed position on the ax
-      object.
-
+- Using the text function with three types of 'zdir' values: None, an axis
+  name (ex. 'x'), or a direction tuple (ex. (1, 1, 0)).
+- Using the text function with the color keyword.
+- Using the text2D function to place text on a fixed position on the ax
+  object.
 """
 
 import matplotlib.pyplot as plt
 
 
-fig = plt.figure()
-ax = fig.gca(projection='3d')
+ax = plt.figure().add_subplot(projection='3d')
 
 # Demo 1: zdir
 zdirs = (None, 'x', 'y', 'z', (1, 1, 0), (1, 1, 1))
