@@ -9,25 +9,21 @@ A very simple 'animation' of a 3D plot.  See also rotate_axes3d_demo.
 intentionally takes a long time to run)
 """
 
-
-# This import registers the 3D projection, but is otherwise unused.
-from mpl_toolkits.mplot3d import Axes3D  # noqa: F401 unused import
-
 import matplotlib.pyplot as plt
 import numpy as np
 import time
 
 
 def generate(X, Y, phi):
-    '''
+    """
     Generates Z data for the points in the X, Y meshgrid and parameter phi.
-    '''
+    """
     R = 1 - np.sqrt(X**2 + Y**2)
     return np.cos(2 * np.pi * X + phi) * R
 
 
 fig = plt.figure()
-ax = fig.add_subplot(111, projection='3d')
+ax = fig.add_subplot(projection='3d')
 
 # Make the X, Y meshgrid.
 xs = np.linspace(-1, 1, 50)
