@@ -72,19 +72,14 @@ plt.show()
 
 #############################################################################
 #
-# ------------
+# .. admonition:: References
 #
-# References
-# """"""""""
+#    The use of the following functions, methods, classes and modules is shown
+#    in this example:
 #
-# The use of the following functions, methods, classes and modules is shown
-# in this example:
-
-import matplotlib
-matplotlib.figure.Figure.align_ylabels
-matplotlib.axis.Axis.set_label_coords
-matplotlib.axes.Axes.plot
-matplotlib.pyplot.plot
-matplotlib.axes.Axes.set_title
-matplotlib.axes.Axes.set_ylabel
-matplotlib.axes.Axes.set_ylim
+#    - `matplotlib.figure.Figure.align_ylabels`
+#    - `matplotlib.axis.Axis.set_label_coords`
+#    - `matplotlib.axes.Axes.plot` / `matplotlib.pyplot.plot`
+#    - `matplotlib.axes.Axes.set_title`
+#    - `matplotlib.axes.Axes.set_ylabel`
+#    - `matplotlib.axes.Axes.set_ylim`
