@@ -28,18 +28,14 @@ plt.show()
 
 #############################################################################
 #
-# ------------
+# .. admonition:: References
 #
-# References
-# """"""""""
+#    The use of the following functions, methods, classes and modules is shown
+#    in this example:
 #
-# The use of the following functions, methods, classes and modules is shown
-# in this example:
-
-import matplotlib
-matplotlib.pyplot.hist
-matplotlib.pyplot.xlabel
-matplotlib.pyplot.ylabel
-matplotlib.pyplot.text
-matplotlib.pyplot.grid
-matplotlib.pyplot.show
+#    - `matplotlib.pyplot.hist`
+#    - `matplotlib.pyplot.xlabel`
+#    - `matplotlib.pyplot.ylabel`
+#    - `matplotlib.pyplot.text`
+#    - `matplotlib.pyplot.grid`
+#    - `matplotlib.pyplot.show`
