@@ -31,7 +31,7 @@ def example_plot(ax):
 
 fig, ax = plt.subplots()
 example_plot(ax)
-plt.tight_layout()
+fig.tight_layout()
 
 ###############################################################################
 
@@ -40,61 +40,53 @@ example_plot(ax1)
 example_plot(ax2)
 example_plot(ax3)
 example_plot(ax4)
-plt.tight_layout()
+fig.tight_layout()
 
 ###############################################################################
 
 fig, (ax1, ax2) = plt.subplots(nrows=2, ncols=1)
 example_plot(ax1)
 example_plot(ax2)
-plt.tight_layout()
+fig.tight_layout()
 
 ###############################################################################
 
 fig, (ax1, ax2) = plt.subplots(nrows=1, ncols=2)
 example_plot(ax1)
 example_plot(ax2)
-plt.tight_layout()
+fig.tight_layout()
 
 ###############################################################################
 
 fig, axs = plt.subplots(nrows=3, ncols=3)
 for ax in axs.flat:
     example_plot(ax)
-plt.tight_layout()
+fig.tight_layout()
 
 ###############################################################################
 
-fig = plt.figure()
-
+plt.figure()
 ax1 = plt.subplot(221)
 ax2 = plt.subplot(223)
 ax3 = plt.subplot(122)
-
 example_plot(ax1)
 example_plot(ax2)
 example_plot(ax3)
-
 plt.tight_layout()
 
 ###############################################################################
 
-fig = plt.figure()
-
+plt.figure()
 ax1 = plt.subplot2grid((3, 3), (0, 0))
 ax2 = plt.subplot2grid((3, 3), (0, 1), colspan=2)
 ax3 = plt.subplot2grid((3, 3), (1, 0), colspan=2, rowspan=2)
 ax4 = plt.subplot2grid((3, 3), (1, 2), rowspan=2)
-
 example_plot(ax1)
 example_plot(ax2)
 example_plot(ax3)
 example_plot(ax4)
-
 plt.tight_layout()
 
-plt.show()
-
 ###############################################################################
 
 fig = plt.figure()
@@ -103,20 +95,16 @@ gs1 = fig.add_gridspec(3, 1)
 ax1 = fig.add_subplot(gs1[0])
 ax2 = fig.add_subplot(gs1[1])
 ax3 = fig.add_subplot(gs1[2])
-
 example_plot(ax1)
 example_plot(ax2)
 example_plot(ax3)
-
 gs1.tight_layout(fig, rect=[None, None, 0.45, None])
 
 gs2 = fig.add_gridspec(2, 1)
 ax4 = fig.add_subplot(gs2[0])
 ax5 = fig.add_subplot(gs2[1])
-
 example_plot(ax4)
 example_plot(ax5)
-
 with warnings.catch_warnings():
     # gs2.tight_layout cannot handle the subplots from the first gridspec
     # (gs1), so it will raise a warning. We are going to match the gridspecs
@@ -135,16 +123,13 @@ plt.show()
 
 #############################################################################
 #
-# ------------
+# .. admonition:: References
 #
-# References
-# """"""""""
+#    The use of the following functions, methods, classes and modules is shown
+#    in this example:
 #
-# The use of the following functions and methods is shown in this example:
-
-import matplotlib
-matplotlib.pyplot.tight_layout
-matplotlib.figure.Figure.tight_layout
-matplotlib.figure.Figure.add_gridspec
-matplotlib.figure.Figure.add_subplot
-matplotlib.pyplot.subplot2grid
+#    - `matplotlib.figure.Figure.tight_layout` /
+#      `matplotlib.pyplot.tight_layout`
+#    - `matplotlib.figure.Figure.add_gridspec`
+#    - `matplotlib.figure.Figure.add_subplot`
+#    - `matplotlib.pyplot.subplot2grid`
