@@ -29,10 +29,10 @@ fig, ax = plt.subplots(2, 1)
 
 pcm = ax[0].pcolor(X, Y, Z,
                    norm=colors.LogNorm(vmin=Z.min(), vmax=Z.max()),
-                   cmap='PuBu_r')
+                   cmap='PuBu_r', shading='nearest')
 fig.colorbar(pcm, ax=ax[0], extend='max')
 
-pcm = ax[1].pcolor(X, Y, Z, cmap='PuBu_r')
+pcm = ax[1].pcolor(X, Y, Z, cmap='PuBu_r', shading='nearest')
 fig.colorbar(pcm, ax=ax[1], extend='max')
 
 
@@ -46,10 +46,10 @@ Z1 = (1 + np.sin(Y * 10.)) * X**2
 fig, ax = plt.subplots(2, 1)
 
 pcm = ax[0].pcolormesh(X, Y, Z1, norm=colors.PowerNorm(gamma=1. / 2.),
-                       cmap='PuBu_r')
+                       cmap='PuBu_r', shading='nearest')
 fig.colorbar(pcm, ax=ax[0], extend='max')
 
-pcm = ax[1].pcolormesh(X, Y, Z1, cmap='PuBu_r')
+pcm = ax[1].pcolormesh(X, Y, Z1, cmap='PuBu_r', shading='nearest')
 fig.colorbar(pcm, ax=ax[1], extend='max')
 
 ###############################################################################
@@ -70,13 +70,13 @@ fig, ax = plt.subplots(2, 1)
 pcm = ax[0].pcolormesh(X, Y, Z1,
                        norm=colors.SymLogNorm(linthresh=0.03, linscale=0.03,
                                               vmin=-1.0, vmax=1.0, base=10),
-                       cmap='RdBu_r')
+                       cmap='RdBu_r', shading='nearest')
 fig.colorbar(pcm, ax=ax[0], extend='both')
 
-pcm = ax[1].pcolormesh(X, Y, Z1, cmap='RdBu_r', vmin=-np.max(Z1))
+pcm = ax[1].pcolormesh(X, Y, Z1, cmap='RdBu_r', vmin=-np.max(Z1),
+                       shading='nearest')
 fig.colorbar(pcm, ax=ax[1], extend='both')
 
-
 ###############################################################################
 # Custom Norm: An example with a customized normalization.  This one
 # uses the example above, and normalizes the negative data differently
@@ -94,7 +94,7 @@ Z = (Z1 - Z2) * 2
 class MidpointNormalize(colors.Normalize):
     def __init__(self, vmin=None, vmax=None, midpoint=None, clip=False):
         self.midpoint = midpoint
-        colors.Normalize.__init__(self, vmin, vmax, clip)
+        super().__init__(vmin, vmax, clip)
 
     def __call__(self, value, clip=None):
         # I'm ignoring masked values and all kinds of edge cases to make a
@@ -108,10 +108,11 @@ fig, ax = plt.subplots(2, 1)
 
 pcm = ax[0].pcolormesh(X, Y, Z,
                        norm=MidpointNormalize(midpoint=0.),
-                       cmap='RdBu_r')
+                       cmap='RdBu_r', shading='nearest')
 fig.colorbar(pcm, ax=ax[0], extend='both')
 
-pcm = ax[1].pcolormesh(X, Y, Z, cmap='RdBu_r', vmin=-np.max(Z))
+pcm = ax[1].pcolormesh(X, Y, Z, cmap='RdBu_r', vmin=-np.max(Z),
+                       shading='nearest')
 fig.colorbar(pcm, ax=ax[1], extend='both')
 
 ###############################################################################
@@ -126,16 +127,17 @@ bounds = np.linspace(-1, 1, 10)
 norm = colors.BoundaryNorm(boundaries=bounds, ncolors=256)
 pcm = ax[0].pcolormesh(X, Y, Z,
                        norm=norm,
-                       cmap='RdBu_r')
+                       cmap='RdBu_r', shading='nearest')
 fig.colorbar(pcm, ax=ax[0], extend='both', orientation='vertical')
 
 # uneven bounds changes the colormapping:
 bounds = np.array([-0.25, -0.125, 0, 0.5, 1])
 norm = colors.BoundaryNorm(boundaries=bounds, ncolors=256)
-pcm = ax[1].pcolormesh(X, Y, Z, norm=norm, cmap='RdBu_r')
+pcm = ax[1].pcolormesh(X, Y, Z, norm=norm, cmap='RdBu_r', shading='nearest')
 fig.colorbar(pcm, ax=ax[1], extend='both', orientation='vertical')
 
-pcm = ax[2].pcolormesh(X, Y, Z, cmap='RdBu_r', vmin=-np.max(Z1))
+pcm = ax[2].pcolormesh(X, Y, Z, cmap='RdBu_r', vmin=-np.max(Z1),
+                       shading='nearest')
 fig.colorbar(pcm, ax=ax[2], extend='both', orientation='vertical')
 
 plt.show()
