@@ -10,7 +10,7 @@ user presses enter in the textbox or leaves the textbox.
 
 Note:  The `matplotlib.widgets.TextBox` widget is different from the following
 static elements: :doc:`/tutorials/text/annotations` and
-:doc:`/gallery/recipes/placing_text_boxes`.
+:doc:`/gallery/text_labels_and_annotations/placing_text_boxes`.
 """
 
 import numpy as np
@@ -40,7 +40,7 @@ def submit(expression):
 
 
 axbox = fig.add_axes([0.1, 0.05, 0.8, 0.075])
-text_box = TextBox(axbox, "Evaluate")
+text_box = TextBox(axbox, "Evaluate", textalignment="center")
 text_box.on_submit(submit)
 text_box.set_val("t ** 2")  # Trigger `submit` with the initial string.
 
@@ -48,12 +48,9 @@ plt.show()
 
 #############################################################################
 #
-# ------------
+# .. admonition:: References
 #
-# References
-# """"""""""
+#    The use of the following functions, methods, classes and modules is shown
+#    in this example:
 #
-# The use of the following functions, methods, classes and modules is shown
-# in this example:
-
-from matplotlib.widgets import TextBox
+#    - `matplotlib.widgets.TextBox`
