@@ -1,16 +1,31 @@
 """
-A module providing some utility functions regarding bezier path manipulation.
+A module providing some utility functions regarding Bezier path manipulation.
 """
 
+from functools import lru_cache
+import math
+import warnings
+
 import numpy as np
 
-import matplotlib.cbook as cbook
-from matplotlib.path import Path
+from matplotlib import _api
+
+
+# same algorithm as 3.8's math.comb
+@np.vectorize
+@lru_cache(maxsize=128)
+def _comb(n, k):
+    if k > n:
+        return 0
+    k = min(k, n - k)
+    i = np.arange(1, k + 1)
+    return np.prod((n + 1 - i)/i).astype(int)
 
 
 class NonIntersectingPathException(ValueError):
     pass
 
+
 # some functions
 
 
@@ -18,7 +33,7 @@ def get_intersection(cx1, cy1, cos_t1, sin_t1,
                      cx2, cy2, cos_t2, sin_t2):
     """
     Return the intersection between the line through (*cx1*, *cy1*) at angle
-    *t1* and the line through (*cx2, cy2) at angle *t2*.
+    *t1* and the line through (*cx2*, *cy2*) at angle *t2*.
     """
 
     # line1 => sin_t1 * (x - cx1) - cos_t1 * (y - cy1) = 0.
@@ -32,7 +47,7 @@ def get_intersection(cx1, cy1, cos_t1, sin_t1,
     c, d = sin_t2, -cos_t2
 
     ad_bc = a * d - b * c
-    if np.abs(ad_bc) < 1.0e-12:
+    if abs(ad_bc) < 1e-12:
         raise ValueError("Given lines do not intersect. Please verify that "
                          "the angles are not equal or differ by 180 degrees.")
 
@@ -49,7 +64,7 @@ def get_intersection(cx1, cy1, cos_t1, sin_t1,
 
 def get_normal_points(cx, cy, cos_t, sin_t, length):
     """
-    For a line passing through (*cx*, *cy*) and having a angle *t*, return
+    For a line passing through (*cx*, *cy*) and having an angle *t*, return
     locations of the two points located along its perpendicular line at the
     distance of *length*.
     """
@@ -79,7 +94,7 @@ def _de_casteljau1(beta, t):
 
 def split_de_casteljau(beta, t):
     """
-    Split a bezier segment defined by its control points *beta* into two
+    Split a Bezier segment defined by its control points *beta* into two
     separate segments divided at *t* and return their control points.
     """
     beta = np.asarray(beta)
@@ -95,24 +110,44 @@ def split_de_casteljau(beta, t):
     return left_beta, right_beta
 
 
-@cbook._rename_parameter("3.1", "tolerence", "tolerance")
 def find_bezier_t_intersecting_with_closedpath(
         bezier_point_at_t, inside_closedpath, t0=0., t1=1., tolerance=0.01):
-    """ Find a parameter t0 and t1 of the given bezier path which
-    bounds the intersecting points with a provided closed
-    path(*inside_closedpath*). Search starts from *t0* and *t1* and it
-    uses a simple bisecting algorithm therefore one of the end point
-    must be inside the path while the other doesn't. The search stop
-    when |t0-t1| gets smaller than the given tolerance.
-    value for
-
-    - bezier_point_at_t : a function which returns x, y coordinates at *t*
-
-    - inside_closedpath : return True if the point is inside the path
-
     """
-    # inside_closedpath : function
+    Find the intersection of the Bezier curve with a closed path.
 
+    The intersection point *t* is approximated by two parameters *t0*, *t1*
+    such that *t0* <= *t* <= *t1*.
+
+    Search starts from *t0* and *t1* and uses a simple bisecting algorithm
+    therefore one of the end points must be inside the path while the other
+    doesn't. The search stops when the distance of the points parametrized by
+    *t0* and *t1* gets smaller than the given *tolerance*.
+
+    Parameters
+    ----------
+    bezier_point_at_t : callable
+        A function returning x, y coordinates of the Bezier at parameter *t*.
+        It must have the signature::
+
+            bezier_point_at_t(t: float) -> tuple[float, float]
+
+    inside_closedpath : callable
+        A function returning True if a given point (x, y) is inside the
+        closed path. It must have the signature::
+
+            inside_closedpath(point: tuple[float, float]) -> bool
+
+    t0, t1 : float
+        Start parameters for the search.
+
+    tolerance : float
+        Maximal allowed distance between the final points.
+
+    Returns
+    -------
+    t0, t1 : float
+        The Bezier path parameters.
+    """
     start = bezier_point_at_t(t0)
     end = bezier_point_at_t(t1)
 
@@ -144,47 +179,153 @@ def find_bezier_t_intersecting_with_closedpath(
             start_inside = middle_inside
 
 
-class BezierSegment(object):
-    """
-    A simple class of a 2-dimensional bezier segment
+class BezierSegment:
     """
+    A d-dimensional Bezier segment.
 
-    # Higher order bezier lines can be supported by simplying adding
-    # corresponding values.
-    _binom_coeff = {1: np.array([1., 1.]),
-                    2: np.array([1., 2., 1.]),
-                    3: np.array([1., 3., 3., 1.])}
+    Parameters
+    ----------
+    control_points : (N, d) array
+        Location of the *N* control points.
+    """
 
     def __init__(self, control_points):
-        """
-        *control_points* : location of contol points. It needs have a
-         shape of n * 2, where n is the order of the bezier line. 1<=
-         n <= 3 is supported.
-        """
-        _o = len(control_points)
-        self._orders = np.arange(_o)
+        self._cpoints = np.asarray(control_points)
+        self._N, self._d = self._cpoints.shape
+        self._orders = np.arange(self._N)
+        coeff = [math.factorial(self._N - 1)
+                 // (math.factorial(i) * math.factorial(self._N - 1 - i))
+                 for i in range(self._N)]
+        self._px = (self._cpoints.T * coeff).T
 
-        _coeff = BezierSegment._binom_coeff[_o - 1]
-        xx, yy = np.asarray(control_points).T
-        self._px = xx * _coeff
-        self._py = yy * _coeff
+    def __call__(self, t):
+        """
+        Evaluate the Bezier curve at point(s) t in [0, 1].
+
+        Parameters
+        ----------
+        t : (k,) array-like
+            Points at which to evaluate the curve.
+
+        Returns
+        -------
+        (k, d) array
+            Value of the curve for each point in *t*.
+        """
+        t = np.asarray(t)
+        return (np.power.outer(1 - t, self._orders[::-1])
+                * np.power.outer(t, self._orders)) @ self._px
 
     def point_at_t(self, t):
-        "evaluate a point at t"
-        tt = ((1 - t) ** self._orders)[::-1] * t ** self._orders
-        _x = np.dot(tt, self._px)
-        _y = np.dot(tt, self._py)
-        return _x, _y
+        """
+        Evaluate the curve at a single point, returning a tuple of *d* floats.
+        """
+        return tuple(self(t))
+
+    @property
+    def control_points(self):
+        """The control points of the curve."""
+        return self._cpoints
+
+    @property
+    def dimension(self):
+        """The dimension of the curve."""
+        return self._d
+
+    @property
+    def degree(self):
+        """Degree of the polynomial. One less the number of control points."""
+        return self._N - 1
+
+    @property
+    def polynomial_coefficients(self):
+        r"""
+        The polynomial coefficients of the Bezier curve.
+
+        .. warning:: Follows opposite convention from `numpy.polyval`.
+
+        Returns
+        -------
+        (n+1, d) array
+            Coefficients after expanding in polynomial basis, where :math:`n`
+            is the degree of the bezier curve and :math:`d` its dimension.
+            These are the numbers (:math:`C_j`) such that the curve can be
+            written :math:`\sum_{j=0}^n C_j t^j`.
+
+        Notes
+        -----
+        The coefficients are calculated as
+
+        .. math::
+
+            {n \choose j} \sum_{i=0}^j (-1)^{i+j} {j \choose i} P_i
+
+        where :math:`P_i` are the control points of the curve.
+        """
+        n = self.degree
+        # matplotlib uses n <= 4. overflow plausible starting around n = 15.
+        if n > 10:
+            warnings.warn("Polynomial coefficients formula unstable for high "
+                          "order Bezier curves!", RuntimeWarning)
+        P = self.control_points
+        j = np.arange(n+1)[:, None]
+        i = np.arange(n+1)[None, :]  # _comb is non-zero for i <= j
+        prefactor = (-1)**(i + j) * _comb(j, i)  # j on axis 0, i on axis 1
+        return _comb(n, j) * prefactor @ P  # j on axis 0, self.dimension on 1
+
+    def axis_aligned_extrema(self):
+        """
+        Return the dimension and location of the curve's interior extrema.
+
+        The extrema are the points along the curve where one of its partial
+        derivatives is zero.
+
+        Returns
+        -------
+        dims : array of int
+            Index :math:`i` of the partial derivative which is zero at each
+            interior extrema.
+        dzeros : array of float
+            Of same size as dims. The :math:`t` such that :math:`d/dx_i B(t) =
+            0`
+        """
+        n = self.degree
+        if n <= 1:
+            return np.array([]), np.array([])
+        Cj = self.polynomial_coefficients
+        dCj = np.arange(1, n+1)[:, None] * Cj[1:]
+        dims = []
+        roots = []
+        for i, pi in enumerate(dCj.T):
+            r = np.roots(pi[::-1])
+            roots.append(r)
+            dims.append(np.full_like(r, i))
+        roots = np.concatenate(roots)
+        dims = np.concatenate(dims)
+        in_range = np.isreal(roots) & (roots >= 0) & (roots <= 1)
+        return dims[in_range], np.real(roots)[in_range]
 
 
-@cbook._rename_parameter("3.1", "tolerence", "tolerance")
 def split_bezier_intersecting_with_closedpath(
         bezier, inside_closedpath, tolerance=0.01):
-
     """
-    bezier : control points of the bezier segment
-    inside_closedpath : a function which returns true if the point is inside
-                        the path
+    Split a Bezier curve into two at the intersection with a closed path.
+
+    Parameters
+    ----------
+    bezier : (N, 2) array-like
+        Control points of the Bezier segment. See `.BezierSegment`.
+    inside_closedpath : callable
+        A function returning True if a given point (x, y) is inside the
+        closed path. See also `.find_bezier_t_intersecting_with_closedpath`.
+    tolerance : float
+        The tolerance for the intersection. See also
+        `.find_bezier_t_intersecting_with_closedpath`.
+
+    Returns
+    -------
+    left, right
+        Lists of control points for the two Bezier segments.
     """
 
     bz = BezierSegment(bezier)
@@ -197,37 +338,15 @@ def split_bezier_intersecting_with_closedpath(
     return _left, _right
 
 
-@cbook.deprecated("3.1")
-@cbook._rename_parameter("3.1", "tolerence", "tolerance")
-def find_r_to_boundary_of_closedpath(
-        inside_closedpath, xy, cos_t, sin_t, rmin=0., rmax=1., tolerance=0.01):
-    """
-    Find a radius r (centered at *xy*) between *rmin* and *rmax* at
-    which it intersect with the path.
-
-    inside_closedpath : function
-    cx, cy : center
-    cos_t, sin_t : cosine and sine for the angle
-    rmin, rmax :
-    """
-
-    cx, cy = xy
-
-    def _f(r):
-        return cos_t * r + cx, sin_t * r + cy
-
-    find_bezier_t_intersecting_with_closedpath(
-        _f, inside_closedpath, t0=rmin, t1=rmax, tolerance=tolerance)
-
 # matplotlib specific
 
 
-@cbook._rename_parameter("3.1", "tolerence", "tolerance")
 def split_path_inout(path, inside, tolerance=0.01, reorder_inout=False):
-    """ divide a path into two segment at the point where inside(x, y)
-    becomes False.
     """
-
+    Divide a path into two segments at the point where ``inside(x, y)`` becomes
+    False.
+    """
+    from .path import Path
     path_iter = path.iter_segments()
 
     ctl_points, command = next(path_iter)
@@ -235,8 +354,6 @@ def split_path_inout(path, inside, tolerance=0.01, reorder_inout=False):
 
     ctl_points_old = ctl_points
 
-    concat = np.concatenate
-
     iold = 0
     i = 1
 
@@ -244,7 +361,7 @@ def split_path_inout(path, inside, tolerance=0.01, reorder_inout=False):
         iold = i
         i += len(ctl_points) // 2
         if inside(ctl_points[-2:]) != begin_inside:
-            bezier_path = concat([ctl_points_old[-2:], ctl_points])
+            bezier_path = np.concatenate([ctl_points_old[-2:], ctl_points])
             break
         ctl_points_old = ctl_points
     else:
@@ -269,15 +386,15 @@ def split_path_inout(path, inside, tolerance=0.01, reorder_inout=False):
     verts_right = right[:]
 
     if path.codes is None:
-        path_in = Path(concat([path.vertices[:i], verts_left]))
-        path_out = Path(concat([verts_right, path.vertices[i:]]))
+        path_in = Path(np.concatenate([path.vertices[:i], verts_left]))
+        path_out = Path(np.concatenate([verts_right, path.vertices[i:]]))
 
     else:
-        path_in = Path(concat([path.vertices[:iold], verts_left]),
-                       concat([path.codes[:iold], codes_left]))
+        path_in = Path(np.concatenate([path.vertices[:iold], verts_left]),
+                       np.concatenate([path.codes[:iold], codes_left]))
 
-        path_out = Path(concat([verts_right, path.vertices[i:]]),
-                        concat([codes_right, path.codes[i:]]))
+        path_out = Path(np.concatenate([verts_right, path.vertices[i:]]),
+                        np.concatenate([codes_right, path.codes[i:]]))
 
     if reorder_inout and not begin_inside:
         path_in, path_out = path_out, path_in
@@ -286,6 +403,14 @@ def split_path_inout(path, inside, tolerance=0.01, reorder_inout=False):
 
 
 def inside_circle(cx, cy, r):
+    """
+    Return a function that checks whether a point is in a circle with center
+    (*cx*, *cy*) and radius *r*.
+
+    The returned function has the signature::
+
+        f(xy: tuple[float, float]) -> bool
+    """
     r2 = r ** 2
 
     def _f(xy):
@@ -294,7 +419,7 @@ def inside_circle(cx, cy, r):
     return _f
 
 
-# quadratic bezier lines
+# quadratic Bezier lines
 
 def get_cos_sin(x0, y0, x1, y1):
     dx, dy = x1 - x0, y1 - y0
@@ -305,19 +430,31 @@ def get_cos_sin(x0, y0, x1, y1):
     return dx / d, dy / d
 
 
-@cbook._rename_parameter("3.1", "tolerence", "tolerance")
 def check_if_parallel(dx1, dy1, dx2, dy2, tolerance=1.e-5):
-    """ returns
-       * 1 if two lines are parallel in same direction
-       * -1 if two lines are parallel in opposite direction
-       * 0 otherwise
+    """
+    Check if two lines are parallel.
+
+    Parameters
+    ----------
+    dx1, dy1, dx2, dy2 : float
+        The gradients *dy*/*dx* of the two lines.
+    tolerance : float
+        The angular tolerance in radians up to which the lines are considered
+        parallel.
+
+    Returns
+    -------
+    is_parallel
+        - 1 if two lines are parallel in same direction.
+        - -1 if two lines are parallel in opposite direction.
+        - False otherwise.
     """
     theta1 = np.arctan2(dx1, dy1)
     theta2 = np.arctan2(dx2, dy2)
-    dtheta = np.abs(theta1 - theta2)
+    dtheta = abs(theta1 - theta2)
     if dtheta < tolerance:
         return 1
-    elif np.abs(dtheta - np.pi) < tolerance:
+    elif abs(dtheta - np.pi) < tolerance:
         return -1
     else:
         return False
@@ -325,14 +462,14 @@ def check_if_parallel(dx1, dy1, dx2, dy2, tolerance=1.e-5):
 
 def get_parallels(bezier2, width):
     """
-    Given the quadratic bezier control points *bezier2*, returns
-    control points of quadratic bezier lines roughly parallel to given
+    Given the quadratic Bezier control points *bezier2*, returns
+    control points of quadratic Bezier lines roughly parallel to given
     one separated by *width*.
     """
 
-    # The parallel bezier lines are constructed by following ways.
+    # The parallel Bezier lines are constructed by following ways.
     #  c1 and c2 are control points representing the begin and end of the
-    #  bezier line.
+    #  Bezier line.
     #  cm is the middle point
 
     c1x, c1y = bezier2[0]
@@ -343,7 +480,7 @@ def get_parallels(bezier2, width):
                                       cmx - c2x, cmy - c2y)
 
     if parallel_test == -1:
-        cbook._warn_external(
+        _api.warn_external(
             "Lines do not intersect. A straight line is used instead.")
         cos_t1, sin_t1 = get_cos_sin(c1x, c1y, c2x, c2y)
         cos_t2, sin_t2 = cos_t1, sin_t1
@@ -355,7 +492,7 @@ def get_parallels(bezier2, width):
 
     # find c1_left, c1_right which are located along the lines
     # through c1 and perpendicular to the tangential lines of the
-    # bezier path at a distance of width. Same thing for c2_left and
+    # Bezier path at a distance of width. Same thing for c2_left and
     # c2_right with respect to c2.
     c1x_left, c1y_left, c1x_right, c1y_right = (
         get_normal_points(c1x, c1y, cos_t1, sin_t1, width)
@@ -367,25 +504,25 @@ def get_parallels(bezier2, width):
     # find cm_left which is the intersecting point of a line through
     # c1_left with angle t1 and a line through c2_left with angle
     # t2. Same with cm_right.
-    if parallel_test != 0:
-        # a special case for a straight line, i.e., angle between two
-        # lines are smaller than some (arbitrary) value.
+    try:
+        cmx_left, cmy_left = get_intersection(c1x_left, c1y_left, cos_t1,
+                                              sin_t1, c2x_left, c2y_left,
+                                              cos_t2, sin_t2)
+        cmx_right, cmy_right = get_intersection(c1x_right, c1y_right, cos_t1,
+                                                sin_t1, c2x_right, c2y_right,
+                                                cos_t2, sin_t2)
+    except ValueError:
+        # Special case straight lines, i.e., angle between two lines is
+        # less than the threshold used by get_intersection (we don't use
+        # check_if_parallel as the threshold is not the same).
         cmx_left, cmy_left = (
             0.5 * (c1x_left + c2x_left), 0.5 * (c1y_left + c2y_left)
         )
         cmx_right, cmy_right = (
             0.5 * (c1x_right + c2x_right), 0.5 * (c1y_right + c2y_right)
         )
-    else:
-        cmx_left, cmy_left = get_intersection(c1x_left, c1y_left, cos_t1,
-                                              sin_t1, c2x_left, c2y_left,
-                                              cos_t2, sin_t2)
 
-        cmx_right, cmy_right = get_intersection(c1x_right, c1y_right, cos_t1,
-                                                sin_t1, c2x_right, c2y_right,
-                                                cos_t2, sin_t2)
-
-    # the parallel bezier lines are created with control points of
+    # the parallel Bezier lines are created with control points of
     # [c1_left, cm_left, c2_left] and [c1_right, cm_right, c2_right]
     path_left = [(c1x_left, c1y_left),
                  (cmx_left, cmy_left),
@@ -410,7 +547,7 @@ def find_control_points(c1x, c1y, mmx, mmy, c2x, c2y):
 def make_wedged_bezier2(bezier2, width, w1=1., wm=0.5, w2=0.):
     """
     Being similar to get_parallels, returns control points of two quadratic
-    bezier lines having a width roughly parallel to given one separated by
+    Bezier lines having a width roughly parallel to given one separated by
     *width*.
     """
 
@@ -426,7 +563,7 @@ def make_wedged_bezier2(bezier2, width, w1=1., wm=0.5, w2=0.):
 
     # find c1_left, c1_right which are located along the lines
     # through c1 and perpendicular to the tangential lines of the
-    # bezier path at a distance of width. Same thing for c3_left and
+    # Bezier path at a distance of width. Same thing for c3_left and
     # c3_right with respect to c3.
     c1x_left, c1y_left, c1x_right, c1y_right = (
         get_normal_points(c1x, c1y, cos_t1, sin_t1, width * w1)
@@ -456,25 +593,3 @@ def make_wedged_bezier2(bezier2, width, w1=1., wm=0.5, w2=0.):
                                      c3x_right, c3y_right)
 
     return path_left, path_right
-
-
-def make_path_regular(p):
-    """
-    If the :attr:`codes` attribute of `Path` *p* is None, return a copy of *p*
-    with the :attr:`codes` set to (MOVETO, LINETO, LINETO, ..., LINETO);
-    otherwise return *p* itself.
-    """
-    c = p.codes
-    if c is None:
-        c = np.full(len(p.vertices), Path.LINETO, dtype=Path.code_type)
-        c[0] = Path.MOVETO
-        return Path(p.vertices, c)
-    else:
-        return p
-
-
-def concatenate_paths(paths):
-    """Concatenate a list of paths into a single path."""
-    vertices = np.concatenate([p.vertices for p in paths])
-    codes = np.concatenate([make_path_regular(p).codes for p in paths])
-    return Path(vertices, codes)
