@@ -17,7 +17,7 @@ import logging
 
 import numpy as np
 
-from matplotlib import cbook, ticker, units
+from matplotlib import _api, ticker, units
 
 
 _log = logging.getLogger(__name__)
@@ -50,12 +50,19 @@ class StrCategoryConverter(units.ConversionInterface):
                 'Missing category information for StrCategoryConverter; '
                 'this might be caused by unintendedly mixing categorical and '
                 'numeric data')
+        StrCategoryConverter._validate_unit(unit)
         # dtype = object preserves numerical pass throughs
         values = np.atleast_1d(np.array(value, dtype=object))
         # pass through sequence of non binary numbers
-        if all(units.ConversionInterface.is_numlike(v)
-               and not isinstance(v, (str, bytes))
-               for v in values):
+        with _api.suppress_matplotlib_deprecation_warning():
+            is_numlike = all(units.ConversionInterface.is_numlike(v)
+                             and not isinstance(v, (str, bytes))
+                             for v in values)
+        if is_numlike:
+            _api.warn_deprecated(
+                "3.5", message="Support for passing numbers through unit "
+                "converters is deprecated since %(since)s and support will be "
+                "removed %(removal)s; use Axis.convert_units instead.")
             return np.asarray(values, dtype=float)
         # force an update so it also does type checking
         unit.update(values)
@@ -73,13 +80,15 @@ class StrCategoryConverter(units.ConversionInterface):
         axis : `~matplotlib.axis.Axis`
             axis for which information is being set
 
+            .. note:: *axis* is not used
+
         Returns
         -------
         `~matplotlib.units.AxisInfo`
             Information to support default tick labeling
 
-        .. note: axis is not used
         """
+        StrCategoryConverter._validate_unit(unit)
         # locator and formatter take mapping dict because
         # args need to be pass by reference for updates
         majloc = StrCategoryLocator(unit._mapping)
@@ -109,13 +118,20 @@ class StrCategoryConverter(units.ConversionInterface):
             axis.units.update(data)
         return axis.units
 
+    @staticmethod
+    def _validate_unit(unit):
+        if not hasattr(unit, '_mapping'):
+            raise ValueError(
+                f'Provided unit "{unit}" is not valid for a categorical '
+                'converter, as it does not have a _mapping attribute.')
+
 
 class StrCategoryLocator(ticker.Locator):
     """Tick at every integer mapping of the string data."""
     def __init__(self, units_mapping):
         """
         Parameters
-        -----------
+        ----------
         units_mapping : dict
             Mapping of category names (str) to indices (int).
         """
@@ -208,7 +224,7 @@ class UnitData:
         convertible = True
         for val in OrderedDict.fromkeys(data):
             # OrderedDict just iterates over unique values in data.
-            cbook._check_isinstance((str, bytes), value=val)
+            _api.check_isinstance((str, bytes), value=val)
             if convertible:
                 # this will only be called so long as convertible is True.
                 convertible = self._str_is_convertible(val)
