@@ -3,7 +3,9 @@ Utilities for comparing image results.
 """
 
 import atexit
+import functools
 import hashlib
+import logging
 import os
 from pathlib import Path
 import re
@@ -11,6 +13,7 @@ import shutil
 import subprocess
 import sys
 from tempfile import TemporaryDirectory, TemporaryFile
+import weakref
 
 import numpy as np
 from PIL import Image
@@ -19,7 +22,9 @@ import matplotlib as mpl
 from matplotlib import cbook
 from matplotlib.testing.exceptions import ImageComparisonFailure
 
-__all__ = ['compare_images', 'comparable_formats']
+_log = logging.getLogger(__name__)
+
+__all__ = ['calculate_rms', 'comparable_formats', 'compare_images']
 
 
 def make_test_filename(fname, purpose):
@@ -30,10 +35,14 @@ def make_test_filename(fname, purpose):
     return '%s-%s%s' % (base, purpose, ext)
 
 
-def get_cache_dir():
+def _get_cache_path():
     cache_dir = Path(mpl.get_cachedir(), 'test_cache')
     cache_dir.mkdir(parents=True, exist_ok=True)
-    return str(cache_dir)
+    return cache_dir
+
+
+def get_cache_dir():
+    return str(_get_cache_path())
 
 
 def get_file_hash(path, block_size=2 ** 20):
@@ -55,25 +64,6 @@ def get_file_hash(path, block_size=2 ** 20):
     return md5.hexdigest()
 
 
-@cbook.deprecated("3.3")
-def make_external_conversion_command(cmd):
-    def convert(old, new):
-        cmdline = cmd(old, new)
-        pipe = subprocess.Popen(cmdline, universal_newlines=True,
-                                stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        stdout, stderr = pipe.communicate()
-        errcode = pipe.wait()
-        if not os.path.exists(new) or errcode:
-            msg = "Conversion command failed:\n%s\n" % ' '.join(cmdline)
-            if stdout:
-                msg += "Standard output:\n%s\n" % stdout
-            if stderr:
-                msg += "Standard error:\n%s\n" % stderr
-            raise IOError(msg)
-
-    return convert
-
-
 # Modified from https://bugs.python.org/issue25567.
 _find_unsafe_bytes = re.compile(br'[^a-zA-Z0-9_@%+=:,./-]').search
 
@@ -115,7 +105,7 @@ class _Converter:
                 raise _ConverterError
             buf.extend(c)
             if buf.endswith(terminator):
-                return bytes(buf[:-len(terminator)])
+                return bytes(buf)
 
 
 class _GSConverter(_Converter):
@@ -145,23 +135,25 @@ class _GSConverter(_Converter):
             + b") run flush\n")
         self._proc.stdin.flush()
         # GS> if nothing left on the stack; GS<n> if n items left on the stack.
-        err = self._read_until(b"GS")
-        stack = self._read_until(b">")
+        err = self._read_until((b"GS<", b"GS>"))
+        stack = self._read_until(b">") if err.endswith(b"GS<") else b""
         if stack or not os.path.exists(dest):
-            stack_size = int(stack[1:]) if stack else 0
+            stack_size = int(stack[:-1]) if stack else 0
             self._proc.stdin.write(b"pop\n" * stack_size)
             # Using the systemencoding should at least get the filenames right.
             raise ImageComparisonFailure(
-                (err + b"GS" + stack + b">")
-                .decode(sys.getfilesystemencoding(), "replace"))
+                (err + stack).decode(sys.getfilesystemencoding(), "replace"))
 
 
 class _SVGConverter(_Converter):
     def __call__(self, orig, dest):
-        old_inkscape = mpl._get_executable_info("inkscape").version < "1"
+        old_inkscape = mpl._get_executable_info("inkscape").version.major < 1
         terminator = b"\n>" if old_inkscape else b"> "
         if not hasattr(self, "_tmpdir"):
             self._tmpdir = TemporaryDirectory()
+            # On Windows, we must make sure that self._proc has terminated
+            # (which __del__ does) before clearing _tmpdir.
+            weakref.finalize(self._tmpdir, self.__del__)
         if (not self._proc  # First run.
                 or self._proc.poll() is not None):  # Inkscape terminated.
             env = {
@@ -268,8 +260,9 @@ def convert(filename, cache):
 
     If *cache* is True, the result of the conversion is cached in
     `matplotlib.get_cachedir() + '/test_cache/'`.  The caching is based on a
-    hash of the exact contents of the input file.  There is no limit on the
-    size of the cache, so it may need to be manually cleared periodically.
+    hash of the exact contents of the input file.  Old cache entries are
+    automatically deleted as needed to keep the size of the cache capped to
+    twice the size of all baseline images.
     """
     path = Path(filename)
     if not path.exists():
@@ -282,23 +275,55 @@ def convert(filename, cache):
     # Only convert the file if the destination doesn't already exist or
     # is out of date.
     if not newpath.exists() or newpath.stat().st_mtime < path.stat().st_mtime:
-        cache_dir = Path(get_cache_dir()) if cache else None
+        cache_dir = _get_cache_path() if cache else None
 
         if cache_dir is not None:
+            _register_conversion_cache_cleaner_once()
             hash_value = get_file_hash(path)
             cached_path = cache_dir / (hash_value + newpath.suffix)
             if cached_path.exists():
+                _log.debug("For %s: reusing cached conversion.", filename)
                 shutil.copyfile(cached_path, newpath)
                 return str(newpath)
 
+        _log.debug("For %s: converting to png.", filename)
         converter[path.suffix[1:]](path, newpath)
 
         if cache_dir is not None:
+            _log.debug("For %s: caching conversion result.", filename)
             shutil.copyfile(newpath, cached_path)
 
     return str(newpath)
 
 
+def _clean_conversion_cache():
+    # This will actually ignore mpl_toolkits baseline images, but they're
+    # relatively small.
+    baseline_images_size = sum(
+        path.stat().st_size
+        for path in Path(mpl.__file__).parent.glob("**/baseline_images/**/*"))
+    # 2x: one full copy of baselines, and one full copy of test results
+    # (actually an overestimate: we don't convert png baselines and results).
+    max_cache_size = 2 * baseline_images_size
+    # Reduce cache until it fits.
+    with cbook._lock_path(_get_cache_path()):
+        cache_stat = {
+            path: path.stat() for path in _get_cache_path().glob("*")}
+        cache_size = sum(stat.st_size for stat in cache_stat.values())
+        paths_by_atime = sorted(  # Oldest at the end.
+            cache_stat, key=lambda path: cache_stat[path].st_atime,
+            reverse=True)
+        while cache_size > max_cache_size:
+            path = paths_by_atime.pop()
+            cache_size -= cache_stat[path].st_size
+            path.unlink()
+
+
+@functools.lru_cache()  # Ensure this is only registered once.
+def _register_conversion_cache_cleaner_once():
+    atexit.register(_clean_conversion_cache)
+
+
 def crop_to_same(actual_path, actual_image, expected_path, expected_image):
     # clip the images to the same size -- this is useful only when
     # comparing eps to pdf
@@ -387,7 +412,7 @@ def compare_images(expected, actual, tol, in_decorator=False):
         raise IOError('Baseline image %r does not exist.' % expected)
     extension = expected.split('.')[-1]
     if extension != 'png':
-        actual = convert(actual, cache=False)
+        actual = convert(actual, cache=True)
         expected = convert(expected, cache=True)
 
     # open the image files and remove the alpha channel (if it exists)
