@@ -1,7 +1,7 @@
 import pytest
 import sys
 import matplotlib
-from matplotlib import cbook
+from matplotlib import _api, cbook
 
 
 def pytest_configure(config):
@@ -13,11 +13,17 @@ def pytest_configure(config):
         ("markers", "flaky: (Provided by pytest-rerunfailures.)"),
         ("markers", "timeout: (Provided by pytest-timeout.)"),
         ("markers", "backend: Set alternate Matplotlib backend temporarily."),
-        ("markers", "style: Set alternate Matplotlib style temporarily."),
+        ("markers",
+         "style: Set alternate Matplotlib style temporarily (deprecated)."),
         ("markers", "baseline_images: Compare output against references."),
         ("markers", "pytz: Tests that require pytz to be installed."),
         ("markers", "network: Tests that reach out to the network."),
         ("filterwarnings", "error"),
+        ("filterwarnings",
+         "ignore:.*The py23 module has been deprecated:DeprecationWarning"),
+        ("filterwarnings",
+         r"ignore:DynamicImporter.find_spec\(\) not found; "
+         r"falling back to find_module\(\):ImportWarning"),
     ]:
         config.addinivalue_line(key, value)
 
@@ -47,28 +53,9 @@ def mpl_test_settings(request):
             prev_backend = matplotlib.get_backend()
 
             # special case Qt backend importing to avoid conflicts
-            if backend.lower().startswith('qt4'):
-                if any(k in sys.modules for k in ('PyQt5', 'PySide2')):
-                    pytest.skip('Qt5 binding already imported')
-                try:
-                    import PyQt4
-                # RuntimeError if PyQt5 already imported.
-                except (ImportError, RuntimeError):
-                    try:
-                        import PySide
-                    except ImportError:
-                        pytest.skip("Failed to import a Qt4 binding.")
-            elif backend.lower().startswith('qt5'):
-                if any(k in sys.modules for k in ('PyQt4', 'PySide')):
+            if backend.lower().startswith('qt5'):
+                if any(sys.modules.get(k) for k in ('PyQt4', 'PySide')):
                     pytest.skip('Qt4 binding already imported')
-                try:
-                    import PyQt5
-                # RuntimeError if PyQt4 already imported.
-                except (ImportError, RuntimeError):
-                    try:
-                        import PySide2
-                    except ImportError:
-                        pytest.skip("Failed to import a Qt5 binding.")
 
         # Default of cleanup and image_comparison too.
         style = ["classic", "_classic_test_patch"]
@@ -76,10 +63,12 @@ def mpl_test_settings(request):
         if style_marker is not None:
             assert len(style_marker.args) == 1, \
                 "Marker 'style' must specify 1 style."
+            _api.warn_deprecated("3.5", name="style", obj_type="pytest marker",
+                                 alternative="@mpl.style.context(...)")
             style, = style_marker.args
 
         matplotlib.testing.setup()
-        with cbook._suppress_matplotlib_deprecation_warning():
+        with _api.suppress_matplotlib_deprecation_warning():
             if backend is not None:
                 # This import must come after setup() so it doesn't load the
                 # default backend prematurely.
@@ -103,6 +92,7 @@ def mpl_test_settings(request):
 
 
 @pytest.fixture
+@_api.deprecated("3.5", alternative="none")
 def mpl_image_comparison_parameters(request, extension):
     # This fixture is applied automatically by the image_comparison decorator.
     #
