@@ -1,6 +1,5 @@
 import itertools
 import pickle
-import re
 
 from weakref import ref
 from unittest.mock import patch, Mock
@@ -12,9 +11,10 @@ from numpy.testing import (assert_array_equal, assert_approx_equal,
                            assert_array_almost_equal)
 import pytest
 
+from matplotlib import _api
 import matplotlib.cbook as cbook
 import matplotlib.colors as mcolors
-from matplotlib.cbook import MatplotlibDeprecationWarning, delete_masked_points
+from matplotlib.cbook import delete_masked_points
 
 
 class Test_delete_masked_points:
@@ -145,7 +145,6 @@ class Test_boxplot_stats:
     def test_results_withlabels(self):
         labels = ['Test1', 2, 'ardvark', 4]
         results = cbook.boxplot_stats(self.data, labels=labels)
-        res = results[0]
         for lab, res in zip(labels, results):
             assert res['label'] == lab
 
@@ -183,18 +182,34 @@ class Test_callback_registry:
         self.signal = 'test'
         self.callbacks = cbook.CallbackRegistry()
 
-    def connect(self, s, func):
-        return self.callbacks.connect(s, func)
+    def connect(self, s, func, pickle):
+        cid = self.callbacks.connect(s, func)
+        if pickle:
+            self.callbacks._pickled_cids.add(cid)
+        return cid
+
+    def disconnect(self, cid):
+        return self.callbacks.disconnect(cid)
+
+    def count(self):
+        count1 = len(self.callbacks._func_cid_map.get(self.signal, []))
+        count2 = len(self.callbacks.callbacks.get(self.signal))
+        assert count1 == count2
+        return count1
 
     def is_empty(self):
+        np.testing.break_cycles()
         assert self.callbacks._func_cid_map == {}
         assert self.callbacks.callbacks == {}
+        assert self.callbacks._pickled_cids == set()
 
     def is_not_empty(self):
+        np.testing.break_cycles()
         assert self.callbacks._func_cid_map != {}
         assert self.callbacks.callbacks != {}
 
-    def test_callback_complete(self):
+    @pytest.mark.parametrize('pickle', [True, False])
+    def test_callback_complete(self, pickle):
         # ensure we start with an empty registry
         self.is_empty()
 
@@ -202,12 +217,12 @@ class Test_callback_registry:
         mini_me = Test_callback_registry()
 
         # test that we can add a callback
-        cid1 = self.connect(self.signal, mini_me.dummy)
+        cid1 = self.connect(self.signal, mini_me.dummy, pickle)
         assert type(cid1) == int
         self.is_not_empty()
 
         # test that we don't add a second callback
-        cid2 = self.connect(self.signal, mini_me.dummy)
+        cid2 = self.connect(self.signal, mini_me.dummy, pickle)
         assert cid1 == cid2
         self.is_not_empty()
         assert len(self.callbacks._func_cid_map) == 1
@@ -218,6 +233,68 @@ class Test_callback_registry:
         # check we now have no callbacks registered
         self.is_empty()
 
+    @pytest.mark.parametrize('pickle', [True, False])
+    def test_callback_disconnect(self, pickle):
+        # ensure we start with an empty registry
+        self.is_empty()
+
+        # create a class for testing
+        mini_me = Test_callback_registry()
+
+        # test that we can add a callback
+        cid1 = self.connect(self.signal, mini_me.dummy, pickle)
+        assert type(cid1) == int
+        self.is_not_empty()
+
+        self.disconnect(cid1)
+
+        # check we now have no callbacks registered
+        self.is_empty()
+
+    @pytest.mark.parametrize('pickle', [True, False])
+    def test_callback_wrong_disconnect(self, pickle):
+        # ensure we start with an empty registry
+        self.is_empty()
+
+        # create a class for testing
+        mini_me = Test_callback_registry()
+
+        # test that we can add a callback
+        cid1 = self.connect(self.signal, mini_me.dummy, pickle)
+        assert type(cid1) == int
+        self.is_not_empty()
+
+        self.disconnect("foo")
+
+        # check we still have callbacks registered
+        self.is_not_empty()
+
+    @pytest.mark.parametrize('pickle', [True, False])
+    def test_registration_on_non_empty_registry(self, pickle):
+        # ensure we start with an empty registry
+        self.is_empty()
+
+        # setup the registry with a callback
+        mini_me = Test_callback_registry()
+        self.connect(self.signal, mini_me.dummy, pickle)
+
+        # Add another callback
+        mini_me2 = Test_callback_registry()
+        self.connect(self.signal, mini_me2.dummy, pickle)
+
+        # Remove and add the second callback
+        mini_me2 = Test_callback_registry()
+        self.connect(self.signal, mini_me2.dummy, pickle)
+
+        # We still have 2 references
+        self.is_not_empty()
+        assert self.count() == 2
+
+        # Removing the last 2 references
+        mini_me = None
+        mini_me2 = None
+        self.is_empty()
+
     def dummy(self):
         pass
 
@@ -226,26 +303,33 @@ class Test_callback_registry:
                        "callbacks")
 
 
-def test_callbackregistry_default_exception_handler(monkeypatch):
+def test_callbackregistry_default_exception_handler(capsys, monkeypatch):
     cb = cbook.CallbackRegistry()
     cb.connect("foo", lambda: None)
+
     monkeypatch.setattr(
         cbook, "_get_running_interactive_framework", lambda: None)
     with pytest.raises(TypeError):
         cb.process("foo", "argument mismatch")
+    outerr = capsys.readouterr()
+    assert outerr.out == outerr.err == ""
+
     monkeypatch.setattr(
         cbook, "_get_running_interactive_framework", lambda: "not-none")
     cb.process("foo", "argument mismatch")  # No error in that case.
+    outerr = capsys.readouterr()
+    assert outerr.out == ""
+    assert "takes 0 positional arguments but 1 was given" in outerr.err
 
 
 def raising_cb_reg(func):
     class TestException(Exception):
         pass
 
-    def raising_function():
+    def raise_runtime_error():
         raise RuntimeError
 
-    def raising_function_VE():
+    def raise_value_error():
         raise ValueError
 
     def transformer(excp):
@@ -255,15 +339,15 @@ def raising_cb_reg(func):
 
     # old default
     cb_old = cbook.CallbackRegistry(exception_handler=None)
-    cb_old.connect('foo', raising_function)
+    cb_old.connect('foo', raise_runtime_error)
 
     # filter
     cb_filt = cbook.CallbackRegistry(exception_handler=transformer)
-    cb_filt.connect('foo', raising_function)
+    cb_filt.connect('foo', raise_runtime_error)
 
     # filter
     cb_filt_pass = cbook.CallbackRegistry(exception_handler=transformer)
-    cb_filt_pass.connect('foo', raising_function_VE)
+    cb_filt_pass.connect('foo', raise_value_error)
 
     return pytest.mark.parametrize('cb, excp',
                                    [[cb_old, RuntimeError],
@@ -279,6 +363,39 @@ def test_callbackregistry_custom_exception_handler(monkeypatch, cb, excp):
         cb.process('foo')
 
 
+def test_callbackregistry_blocking():
+    # Needs an exception handler for interactive testing environments
+    # that would only print this out instead of raising the exception
+    def raise_handler(excp):
+        raise excp
+    cb = cbook.CallbackRegistry(exception_handler=raise_handler)
+    def test_func1():
+        raise ValueError("1 should be blocked")
+    def test_func2():
+        raise ValueError("2 should be blocked")
+    cb.connect("test1", test_func1)
+    cb.connect("test2", test_func2)
+
+    # block all of the callbacks to make sure they aren't processed
+    with cb.blocked():
+        cb.process("test1")
+        cb.process("test2")
+
+    # block individual callbacks to make sure the other is still processed
+    with cb.blocked(signal="test1"):
+        # Blocked
+        cb.process("test1")
+        # Should raise
+        with pytest.raises(ValueError, match="2 should be blocked"):
+            cb.process("test2")
+
+    # Make sure the original callback functions are there after blocking
+    with pytest.raises(ValueError, match="1 should be blocked"):
+        cb.process("test1")
+    with pytest.raises(ValueError, match="2 should be blocked"):
+        cb.process("test2")
+
+
 def test_sanitize_sequence():
     d = {'a': 1, 'b': 2, 'c': 3}
     k = ['a', 'b', 'c']
@@ -292,45 +409,28 @@ def test_sanitize_sequence():
 
 
 fail_mapping = (
-    ({'a': 1}, {'forbidden': ('a')}),
-    ({'a': 1}, {'required': ('b')}),
-    ({'a': 1, 'b': 2}, {'required': ('a'), 'allowed': ()}),
     ({'a': 1, 'b': 2}, {'alias_mapping': {'a': ['b']}}),
-    ({'a': 1, 'b': 2}, {'alias_mapping': {'a': ['b']}, 'allowed': ('a',)}),
     ({'a': 1, 'b': 2}, {'alias_mapping': {'a': ['a', 'b']}}),
-    ({'a': 1, 'b': 2, 'c': 3},
-     {'alias_mapping': {'a': ['b']}, 'required': ('a', )}),
 )
 
 pass_mapping = (
+    (None, {}, {}),
     ({'a': 1, 'b': 2}, {'a': 1, 'b': 2}, {}),
     ({'b': 2}, {'a': 2}, {'alias_mapping': {'a': ['a', 'b']}}),
-    ({'b': 2}, {'a': 2},
-     {'alias_mapping': {'a': ['b']}, 'forbidden': ('b', )}),
-    ({'a': 1, 'c': 3}, {'a': 1, 'c': 3},
-     {'required': ('a', ), 'allowed': ('c', )}),
-    ({'a': 1, 'c': 3}, {'a': 1, 'c': 3},
-     {'required': ('a', 'c'), 'allowed': ('c', )}),
-    ({'a': 1, 'c': 3}, {'a': 1, 'c': 3},
-     {'required': ('a', 'c'), 'allowed': ('a', 'c')}),
-    ({'a': 1, 'c': 3}, {'a': 1, 'c': 3},
-     {'required': ('a', 'c'), 'allowed': ()}),
-    ({'a': 1, 'c': 3}, {'a': 1, 'c': 3}, {'required': ('a', 'c')}),
-    ({'a': 1, 'c': 3}, {'a': 1, 'c': 3}, {'allowed': ('a', 'c')}),
 )
 
 
 @pytest.mark.parametrize('inp, kwargs_to_norm', fail_mapping)
 def test_normalize_kwargs_fail(inp, kwargs_to_norm):
     with pytest.raises(TypeError), \
-         cbook._suppress_matplotlib_deprecation_warning():
+         _api.suppress_matplotlib_deprecation_warning():
         cbook.normalize_kwargs(inp, **kwargs_to_norm)
 
 
 @pytest.mark.parametrize('inp, expected, kwargs_to_norm',
                          pass_mapping)
 def test_normalize_kwargs_pass(inp, expected, kwargs_to_norm):
-    with cbook._suppress_matplotlib_deprecation_warning():
+    with _api.suppress_matplotlib_deprecation_warning():
         # No other warning should be emitted.
         assert expected == cbook.normalize_kwargs(inp, **kwargs_to_norm)
 
@@ -339,7 +439,7 @@ def test_warn_external_frame_embedded_python():
     with patch.object(cbook, "sys") as mock_sys:
         mock_sys._getframe = Mock(return_value=None)
         with pytest.warns(UserWarning, match=r"\Adummy\Z"):
-            cbook._warn_external("dummy")
+            _api.warn_external("dummy")
 
 
 def test_to_prestep():
@@ -428,9 +528,9 @@ def test_step_fails(args):
 
 
 def test_grouper():
-    class dummy:
+    class Dummy:
         pass
-    a, b, c, d, e = objs = [dummy() for j in range(5)]
+    a, b, c, d, e = objs = [Dummy() for _ in range(5)]
     g = cbook.Grouper()
     g.join(*objs)
     assert set(list(g)[0]) == set(objs)
@@ -448,9 +548,9 @@ def test_grouper():
 
 
 def test_grouper_private():
-    class dummy:
+    class Dummy:
         pass
-    objs = [dummy() for j in range(5)]
+    objs = [Dummy() for _ in range(5)]
     g = cbook.Grouper()
     g.join(*objs)
     # reach in and touch the internals !
@@ -478,13 +578,13 @@ def test_flatiter():
 
 def test_reshape2d():
 
-    class dummy:
+    class Dummy:
         pass
 
     xnew = cbook._reshape_2D([], 'x')
     assert np.shape(xnew) == (1, 0)
 
-    x = [dummy() for j in range(5)]
+    x = [Dummy() for _ in range(5)]
 
     xnew = cbook._reshape_2D(x, 'x')
     assert np.shape(xnew) == (1, 5)
@@ -493,7 +593,7 @@ def test_reshape2d():
     xnew = cbook._reshape_2D(x, 'x')
     assert np.shape(xnew) == (1, 5)
 
-    x = [[dummy() for j in range(5)] for i in range(3)]
+    x = [[Dummy() for _ in range(5)] for _ in range(3)]
     xnew = cbook._reshape_2D(x, 'x')
     assert np.shape(xnew) == (3, 5)
 
@@ -545,6 +645,29 @@ def test_reshape2d():
     assert len(xnew) == 1
     assert isinstance(xnew[0], ArraySubclass)
 
+    # check list of strings:
+    x = ['a', 'b', 'c', 'c', 'dd', 'e', 'f', 'ff', 'f']
+    xnew = cbook._reshape_2D(x, 'x')
+    assert len(xnew[0]) == len(x)
+    assert isinstance(xnew[0], np.ndarray)
+
+
+def test_reshape2d_pandas(pd):
+    # separate to allow the rest of the tests to run if no pandas...
+    X = np.arange(30).reshape(10, 3)
+    x = pd.DataFrame(X, columns=["a", "b", "c"])
+    Xnew = cbook._reshape_2D(x, 'x')
+    # Need to check each row because _reshape_2D returns a list of arrays:
+    for x, xnew in zip(X.T, Xnew):
+        np.testing.assert_array_equal(x, xnew)
+
+    X = np.arange(30).reshape(10, 3)
+    x = pd.DataFrame(X, columns=["a", "b", "c"])
+    Xnew = cbook._reshape_2D(x, 'x')
+    # Need to check each row because _reshape_2D returns a list of arrays:
+    for x, xnew in zip(X.T, Xnew):
+        np.testing.assert_array_equal(x, xnew)
+
 
 def test_contiguous_regions():
     a, b, c = 3, 4, 5
@@ -576,43 +699,8 @@ def test_safe_first_element_pandas_series(pd):
     assert actual == 0
 
 
-def test_delete_parameter():
-    @cbook._delete_parameter("3.0", "foo")
-    def func1(foo=None):
-        pass
-
-    @cbook._delete_parameter("3.0", "foo")
-    def func2(**kwargs):
-        pass
-
-    for func in [func1, func2]:
-        func()  # No warning.
-        with pytest.warns(MatplotlibDeprecationWarning):
-            func(foo="bar")
-
-    def pyplot_wrapper(foo=cbook.deprecation._deprecated_parameter):
-        func1(foo)
-
-    pyplot_wrapper()  # No warning.
-    with pytest.warns(MatplotlibDeprecationWarning):
-        func(foo="bar")
-
-
-def test_make_keyword_only():
-    @cbook._make_keyword_only("3.0", "arg")
-    def func(pre, arg, post=None):
-        pass
-
-    func(1, arg=2)  # Check that no warning is emitted.
-
-    with pytest.warns(MatplotlibDeprecationWarning):
-        func(1, 2)
-    with pytest.warns(MatplotlibDeprecationWarning):
-        func(1, 2, 3)
-
-
 def test_warn_external(recwarn):
-    cbook._warn_external("oops")
+    _api.warn_external("oops")
     assert len(recwarn) == 1
     assert recwarn[0].filename == __file__
 
@@ -645,27 +733,11 @@ def test_array_patch_perimeters():
             check(x, rstride=rstride, cstride=cstride)
 
 
-@pytest.mark.parametrize('target,test_shape',
-                         [((None, ), (1, 3)),
-                          ((None, 3), (1,)),
-                          ((None, 3), (1, 2)),
-                          ((1, 5), (1, 9)),
-                          ((None, 2, None), (1, 3, 1))
-                          ])
-def test_check_shape(target, test_shape):
-    error_pattern = (f"^'aardvark' must be {len(target)}D.*" +
-                     re.escape(f'has shape {test_shape}'))
-    data = np.zeros(test_shape)
-    with pytest.raises(ValueError,
-                       match=error_pattern):
-        cbook._check_shape(target, aardvark=data)
-
-
 def test_setattr_cm():
     class A:
-
         cls_level = object()
         override = object()
+
         def __init__(self):
             self.aardvark = 'aardvark'
             self.override = 'override'
@@ -675,7 +747,7 @@ def test_setattr_cm():
             ...
 
         @classmethod
-        def classy(klass):
+        def classy(cls):
             ...
 
         @staticmethod
@@ -741,3 +813,15 @@ def test_setattr_cm():
         assert a.static == 'static'
 
     verify_pre_post_state(a)
+
+
+def test_format_approx():
+    f = cbook._format_approx
+    assert f(0, 1) == '0'
+    assert f(0, 2) == '0'
+    assert f(0, 3) == '0'
+    assert f(-0.0123, 1) == '-0'
+    assert f(1e-7, 5) == '0'
+    assert f(0.0012345600001, 5) == '0.00123'
+    assert f(-0.0012345600001, 5) == '-0.00123'
+    assert f(0.0012345600001, 8) == f(0.0012345600001, 10) == '0.00123456'
