@@ -6,11 +6,12 @@ import functools
 import numpy as np
 import pytest
 
-from matplotlib import rc_context
+from matplotlib import rc_context, style
 import matplotlib.dates as mdates
 import matplotlib.pyplot as plt
 from matplotlib.testing.decorators import image_comparison
 import matplotlib.ticker as mticker
+import matplotlib._api as _api
 
 
 def test_date_numpyx():
@@ -69,23 +70,63 @@ def test_date2num_NaT_scalar(units):
     assert np.isnan(tmpl)
 
 
-@image_comparison(['date_empty.png'])
 def test_date_empty():
     # make sure we do the right thing when told to plot dates even
     # if no date data has been presented, cf
     # http://sourceforge.net/tracker/?func=detail&aid=2850075&group_id=80706&atid=560720
-    fig = plt.figure()
-    ax = fig.add_subplot(1, 1, 1)
+    fig, ax = plt.subplots()
     ax.xaxis_date()
+    fig.draw_without_rendering()
+    np.testing.assert_allclose(ax.get_xlim(),
+                               [mdates.date2num(np.datetime64('2000-01-01')),
+                                mdates.date2num(np.datetime64('2010-01-01'))])
+
+    mdates._reset_epoch_test_example()
+    mdates.set_epoch('0000-12-31')
+    fig, ax = plt.subplots()
+    ax.xaxis_date()
+    fig.draw_without_rendering()
+    np.testing.assert_allclose(ax.get_xlim(),
+                               [mdates.date2num(np.datetime64('2000-01-01')),
+                                mdates.date2num(np.datetime64('2010-01-01'))])
+    mdates._reset_epoch_test_example()
+
+
+def test_date_not_empty():
+    fig = plt.figure()
+    ax = fig.add_subplot()
+
+    ax.plot([50, 70], [1, 2])
+    ax.xaxis.axis_date()
+    np.testing.assert_allclose(ax.get_xlim(), [50, 70])
+
+
+def test_axhline():
+    # make sure that axhline doesn't set the xlimits...
+    fig, ax = plt.subplots()
+    ax.axhline(1.5)
+    ax.plot([np.datetime64('2016-01-01'), np.datetime64('2016-01-02')], [1, 2])
+    np.testing.assert_allclose(ax.get_xlim(),
+                               [mdates.date2num(np.datetime64('2016-01-01')),
+                                mdates.date2num(np.datetime64('2016-01-02'))])
+
+    mdates._reset_epoch_test_example()
+    mdates.set_epoch('0000-12-31')
+    fig, ax = plt.subplots()
+    ax.axhline(1.5)
+    ax.plot([np.datetime64('2016-01-01'), np.datetime64('2016-01-02')], [1, 2])
+    np.testing.assert_allclose(ax.get_xlim(),
+                               [mdates.date2num(np.datetime64('2016-01-01')),
+                                mdates.date2num(np.datetime64('2016-01-02'))])
+    mdates._reset_epoch_test_example()
 
 
 @image_comparison(['date_axhspan.png'])
 def test_date_axhspan():
-    # test ax hspan with date inputs
+    # test axhspan with date inputs
     t0 = datetime.datetime(2009, 1, 20)
     tf = datetime.datetime(2009, 1, 21)
-    fig = plt.figure()
-    ax = fig.add_subplot(1, 1, 1)
+    fig, ax = plt.subplots()
     ax.axhspan(t0, tf, facecolor="blue", alpha=0.25)
     ax.set_ylim(t0 - datetime.timedelta(days=5),
                 tf + datetime.timedelta(days=5))
@@ -94,11 +135,10 @@ def test_date_axhspan():
 
 @image_comparison(['date_axvspan.png'])
 def test_date_axvspan():
-    # test ax hspan with date inputs
+    # test axvspan with date inputs
     t0 = datetime.datetime(2000, 1, 20)
     tf = datetime.datetime(2010, 1, 21)
-    fig = plt.figure()
-    ax = fig.add_subplot(1, 1, 1)
+    fig, ax = plt.subplots()
     ax.axvspan(t0, tf, facecolor="blue", alpha=0.25)
     ax.set_xlim(t0 - datetime.timedelta(days=720),
                 tf + datetime.timedelta(days=720))
@@ -107,11 +147,10 @@ def test_date_axvspan():
 
 @image_comparison(['date_axhline.png'])
 def test_date_axhline():
-    # test ax hline with date inputs
+    # test axhline with date inputs
     t0 = datetime.datetime(2009, 1, 20)
     tf = datetime.datetime(2009, 1, 31)
-    fig = plt.figure()
-    ax = fig.add_subplot(1, 1, 1)
+    fig, ax = plt.subplots()
     ax.axhline(t0, color="blue", lw=3)
     ax.set_ylim(t0 - datetime.timedelta(days=5),
                 tf + datetime.timedelta(days=5))
@@ -120,11 +159,10 @@ def test_date_axhline():
 
 @image_comparison(['date_axvline.png'])
 def test_date_axvline():
-    # test ax hline with date inputs
+    # test axvline with date inputs
     t0 = datetime.datetime(2000, 1, 20)
     tf = datetime.datetime(2000, 1, 21)
-    fig = plt.figure()
-    ax = fig.add_subplot(1, 1, 1)
+    fig, ax = plt.subplots()
     ax.axvline(t0, color="red", lw=3)
     ax.set_xlim(t0 - datetime.timedelta(days=5),
                 tf + datetime.timedelta(days=5))
@@ -140,8 +178,7 @@ def test_too_many_date_ticks(caplog):
     caplog.set_level("WARNING")
     t0 = datetime.datetime(2000, 1, 20)
     tf = datetime.datetime(2000, 1, 20)
-    fig = plt.figure()
-    ax = fig.add_subplot(1, 1, 1)
+    fig, ax = plt.subplots()
     with pytest.warns(UserWarning) as rec:
         ax.set_xlim((t0, tf), auto=True)
         assert len(rec) == 1
@@ -181,7 +218,7 @@ def test_RRuleLocator():
     tf = datetime.datetime(6000, 1, 1)
 
     fig = plt.figure()
-    ax = plt.subplot(111)
+    ax = plt.subplot()
     ax.set_autoscale_on(True)
     ax.plot([t0, tf], [0.0, 1.0], marker='o')
 
@@ -202,6 +239,18 @@ def test_RRuleLocator_dayrange():
     # On success, no overflow error shall be thrown
 
 
+def test_RRuleLocator_close_minmax():
+    # if d1 and d2 are very close together, rrule cannot create
+    # reasonable tick intervals; ensure that this is handled properly
+    rrule = mdates.rrulewrapper(dateutil.rrule.SECONDLY, interval=5)
+    loc = mdates.RRuleLocator(rrule)
+    d1 = datetime.datetime(year=2020, month=1, day=1)
+    d2 = datetime.datetime(year=2020, month=1, day=1, microsecond=1)
+    expected = ['2020-01-01 00:00:00+00:00',
+                '2020-01-01 00:00:00.000001+00:00']
+    assert list(map(str, mdates.num2date(loc.tick_values(d1, d2)))) == expected
+
+
 @image_comparison(['DateFormatter_fractionalSeconds.png'])
 def test_DateFormatter():
     import matplotlib.testing.jpl_units as units
@@ -214,7 +263,7 @@ def test_DateFormatter():
     tf = datetime.datetime(2001, 1, 1, 0, 0, 1)
 
     fig = plt.figure()
-    ax = plt.subplot(111)
+    ax = plt.subplot()
     ax.set_autoscale_on(True)
     ax.plot([t0, tf], [0.0, 1.0], marker='o')
 
@@ -272,6 +321,30 @@ def test_date_formatter_callable():
     assert formatter([datetime.datetime(2014, 12, 25)]) == ['25-12//2014']
 
 
+@pytest.mark.parametrize('delta, expected', [
+    (datetime.timedelta(weeks=52 * 200),
+     [r'$\mathdefault{%d}$' % year for year in range(1990, 2171, 20)]),
+    (datetime.timedelta(days=30),
+     [r'$\mathdefault{1990{-}01{-}%02d}$' % day for day in range(1, 32, 3)]),
+    (datetime.timedelta(hours=20),
+     [r'$\mathdefault{01{-}01\;%02d}$' % hour for hour in range(0, 21, 2)]),
+    (datetime.timedelta(minutes=10),
+     [r'$\mathdefault{01\;00{:}%02d}$' % minu for minu in range(0, 11)]),
+])
+def test_date_formatter_usetex(delta, expected):
+    style.use("default")
+
+    d1 = datetime.datetime(1990, 1, 1)
+    d2 = d1 + delta
+
+    locator = mdates.AutoDateLocator(interval_multiples=False)
+    locator.create_dummy_axis()
+    locator.axis.set_view_interval(mdates.date2num(d1), mdates.date2num(d2))
+
+    formatter = mdates.AutoDateFormatter(locator, usetex=True)
+    assert [formatter(loc) for loc in locator()] == expected
+
+
 def test_drange():
     """
     This test should check if drange works as expected, and if all the
@@ -305,8 +378,7 @@ def test_auto_date_locator():
     def _create_auto_date_locator(date1, date2):
         locator = mdates.AutoDateLocator(interval_multiples=False)
         locator.create_dummy_axis()
-        locator.set_view_interval(mdates.date2num(date1),
-                                  mdates.date2num(date2))
+        locator.axis.set_view_interval(*mdates.date2num([date1, date2]))
         return locator
 
     d1 = datetime.datetime(1990, 1, 1)
@@ -377,8 +449,7 @@ def test_auto_date_locator_intmult():
     def _create_auto_date_locator(date1, date2):
         locator = mdates.AutoDateLocator(interval_multiples=True)
         locator.create_dummy_axis()
-        locator.set_view_interval(mdates.date2num(date1),
-                                  mdates.date2num(date2))
+        locator.axis.set_view_interval(*mdates.date2num([date1, date2]))
         return locator
 
     results = ([datetime.timedelta(weeks=52 * 200),
@@ -398,11 +469,11 @@ def test_auto_date_locator_intmult():
                  '1997-11-01 00:00:00+00:00', '1997-12-01 00:00:00+00:00']
                 ],
                [datetime.timedelta(days=141),
-                ['1997-01-01 00:00:00+00:00', '1997-01-22 00:00:00+00:00',
-                 '1997-02-01 00:00:00+00:00', '1997-02-22 00:00:00+00:00',
-                 '1997-03-01 00:00:00+00:00', '1997-03-22 00:00:00+00:00',
-                 '1997-04-01 00:00:00+00:00', '1997-04-22 00:00:00+00:00',
-                 '1997-05-01 00:00:00+00:00', '1997-05-22 00:00:00+00:00']
+                ['1997-01-01 00:00:00+00:00', '1997-01-15 00:00:00+00:00',
+                 '1997-02-01 00:00:00+00:00', '1997-02-15 00:00:00+00:00',
+                 '1997-03-01 00:00:00+00:00', '1997-03-15 00:00:00+00:00',
+                 '1997-04-01 00:00:00+00:00', '1997-04-15 00:00:00+00:00',
+                 '1997-05-01 00:00:00+00:00', '1997-05-15 00:00:00+00:00']
                 ],
                [datetime.timedelta(days=40),
                 ['1997-01-01 00:00:00+00:00', '1997-01-05 00:00:00+00:00',
@@ -449,6 +520,17 @@ def test_auto_date_locator_intmult():
         assert list(map(str, mdates.num2date(locator()))) == expected
 
 
+def test_concise_formatter_subsecond():
+    locator = mdates.AutoDateLocator(interval_multiples=True)
+    formatter = mdates.ConciseDateFormatter(locator)
+    year_1996 = 9861.0
+    strings = formatter.format_ticks([
+        year_1996,
+        year_1996 + 500 / mdates.MUSECONDS_PER_DAY,
+        year_1996 + 900 / mdates.MUSECONDS_PER_DAY])
+    assert strings == ['00:00', '00.0005', '00.0009']
+
+
 def test_concise_formatter():
     def _create_auto_date_locator(date1, date2):
         fig, ax = plt.subplots()
@@ -471,8 +553,8 @@ def test_concise_formatter():
                  'Sep', 'Oct', 'Nov', 'Dec']
                 ],
                [datetime.timedelta(days=141),
-                ['Jan', '22', 'Feb', '22', 'Mar', '22', 'Apr', '22',
-                 'May', '22']
+                ['Jan', '15', 'Feb', '15', 'Mar', '15', 'Apr', '15',
+                 'May', '15']
                 ],
                [datetime.timedelta(days=40),
                 ['Jan', '05', '09', '13', '17', '21', '25', '29', 'Feb',
@@ -498,6 +580,85 @@ def test_concise_formatter():
         assert strings == expected
 
 
+@pytest.mark.parametrize('t_delta, expected', [
+    (datetime.timedelta(seconds=0.01), '1997-Jan-01 00:00'),
+    (datetime.timedelta(minutes=1), '1997-Jan-01 00:01'),
+    (datetime.timedelta(hours=1), '1997-Jan-01'),
+    (datetime.timedelta(days=1), '1997-Jan-02'),
+    (datetime.timedelta(weeks=1), '1997-Jan'),
+    (datetime.timedelta(weeks=26), ''),
+    (datetime.timedelta(weeks=520), '')
+])
+def test_concise_formatter_show_offset(t_delta, expected):
+    d1 = datetime.datetime(1997, 1, 1)
+    d2 = d1 + t_delta
+
+    fig, ax = plt.subplots()
+    locator = mdates.AutoDateLocator()
+    formatter = mdates.ConciseDateFormatter(locator)
+    ax.xaxis.set_major_locator(locator)
+    ax.xaxis.set_major_formatter(formatter)
+
+    ax.plot([d1, d2], [0, 0])
+    fig.canvas.draw()
+    assert formatter.get_offset() == expected
+
+
+def test_offset_changes():
+    fig, ax = plt.subplots()
+
+    d1 = datetime.datetime(1997, 1, 1)
+    d2 = d1 + datetime.timedelta(weeks=520)
+
+    locator = mdates.AutoDateLocator()
+    formatter = mdates.ConciseDateFormatter(locator)
+    ax.xaxis.set_major_locator(locator)
+    ax.xaxis.set_major_formatter(formatter)
+
+    ax.plot([d1, d2], [0, 0])
+    fig.draw_without_rendering()
+    assert formatter.get_offset() == ''
+    ax.set_xlim(d1, d1 + datetime.timedelta(weeks=3))
+    fig.draw_without_rendering()
+    assert formatter.get_offset() == '1997-Jan'
+    ax.set_xlim(d1, d1 + datetime.timedelta(weeks=520))
+    fig.draw_without_rendering()
+    assert formatter.get_offset() == ''
+
+
+@pytest.mark.parametrize('t_delta, expected', [
+    (datetime.timedelta(weeks=52 * 200),
+     ['$\\mathdefault{%d}$' % (t, ) for t in range(1980, 2201, 20)]),
+    (datetime.timedelta(days=40),
+     ['Jan', '$\\mathdefault{05}$', '$\\mathdefault{09}$',
+      '$\\mathdefault{13}$', '$\\mathdefault{17}$', '$\\mathdefault{21}$',
+      '$\\mathdefault{25}$', '$\\mathdefault{29}$', 'Feb',
+      '$\\mathdefault{05}$', '$\\mathdefault{09}$']),
+    (datetime.timedelta(hours=40),
+     ['Jan$\\mathdefault{{-}01}$', '$\\mathdefault{04{:}00}$',
+      '$\\mathdefault{08{:}00}$', '$\\mathdefault{12{:}00}$',
+      '$\\mathdefault{16{:}00}$', '$\\mathdefault{20{:}00}$',
+      'Jan$\\mathdefault{{-}02}$', '$\\mathdefault{04{:}00}$',
+      '$\\mathdefault{08{:}00}$', '$\\mathdefault{12{:}00}$',
+      '$\\mathdefault{16{:}00}$']),
+    (datetime.timedelta(seconds=2),
+     ['$\\mathdefault{59.5}$', '$\\mathdefault{00{:}00}$',
+      '$\\mathdefault{00.5}$', '$\\mathdefault{01.0}$',
+      '$\\mathdefault{01.5}$', '$\\mathdefault{02.0}$',
+      '$\\mathdefault{02.5}$']),
+])
+def test_concise_formatter_usetex(t_delta, expected):
+    d1 = datetime.datetime(1997, 1, 1)
+    d2 = d1 + t_delta
+
+    locator = mdates.AutoDateLocator(interval_multiples=True)
+    locator.create_dummy_axis()
+    locator.axis.set_view_interval(mdates.date2num(d1), mdates.date2num(d2))
+
+    formatter = mdates.ConciseDateFormatter(locator, usetex=True)
+    assert formatter.format_ticks(locator()) == expected
+
+
 def test_concise_formatter_formats():
     formats = ['%Y', '%m/%Y', 'day: %d',
                '%H hr %M min', '%H hr %M min', '%S.%f sec']
@@ -523,8 +684,8 @@ def test_concise_formatter_formats():
             '07/1997', '08/1997', '09/1997', '10/1997', '11/1997', '12/1997',
             ]],
         [datetime.timedelta(days=141), [
-            '01/1997', 'day: 22', '02/1997', 'day: 22', '03/1997', 'day: 22',
-            '04/1997', 'day: 22', '05/1997', 'day: 22',
+            '01/1997', 'day: 15', '02/1997', 'day: 15', '03/1997', 'day: 15',
+            '04/1997', 'day: 15', '05/1997', 'day: 15',
             ]],
         [datetime.timedelta(days=40), [
             '01/1997', 'day: 05', 'day: 09', 'day: 13', 'day: 17', 'day: 21',
@@ -578,8 +739,8 @@ def test_concise_formatter_zformats():
                     'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec']
                 ],
                [datetime.timedelta(days=141),
-                ['January', '22', 'February', '22', 'March',
-                    '22', 'April', '22', 'May', '22']
+                ['January', '15', 'February', '15', 'March',
+                    '15', 'April', '15', 'May', '15']
                 ],
                [datetime.timedelta(days=40),
                 ['January', '05', '09', '13', '17', '21',
@@ -650,8 +811,7 @@ def test_auto_date_locator_intmult_tz():
     def _create_auto_date_locator(date1, date2, tz):
         locator = mdates.AutoDateLocator(interval_multiples=True, tz=tz)
         locator.create_dummy_axis()
-        locator.set_view_interval(mdates.date2num(date1),
-                                  mdates.date2num(date2))
+        locator.axis.set_view_interval(*mdates.date2num([date1, date2]))
         return locator
 
     results = ([datetime.timedelta(weeks=52*200),
@@ -671,11 +831,11 @@ def test_auto_date_locator_intmult_tz():
                  '1997-11-01 00:00:00-08:00', '1997-12-01 00:00:00-08:00']
                 ],
                [datetime.timedelta(days=141),
-                ['1997-01-01 00:00:00-08:00', '1997-01-22 00:00:00-08:00',
-                 '1997-02-01 00:00:00-08:00', '1997-02-22 00:00:00-08:00',
-                 '1997-03-01 00:00:00-08:00', '1997-03-22 00:00:00-08:00',
-                 '1997-04-01 00:00:00-08:00', '1997-04-22 00:00:00-07:00',
-                 '1997-05-01 00:00:00-07:00', '1997-05-22 00:00:00-07:00']
+                ['1997-01-01 00:00:00-08:00', '1997-01-15 00:00:00-08:00',
+                 '1997-02-01 00:00:00-08:00', '1997-02-15 00:00:00-08:00',
+                 '1997-03-01 00:00:00-08:00', '1997-03-15 00:00:00-08:00',
+                 '1997-04-01 00:00:00-08:00', '1997-04-15 00:00:00-07:00',
+                 '1997-05-01 00:00:00-07:00', '1997-05-15 00:00:00-07:00']
                 ],
                [datetime.timedelta(days=40),
                 ['1997-01-01 00:00:00-08:00', '1997-01-05 00:00:00-08:00',
@@ -722,8 +882,7 @@ def test_date_inverted_limit():
     # test ax hline with date inputs
     t0 = datetime.datetime(2009, 1, 20)
     tf = datetime.datetime(2009, 1, 31)
-    fig = plt.figure()
-    ax = fig.add_subplot(1, 1, 1)
+    fig, ax = plt.subplots()
     ax.axhline(t0, color="blue", lw=3)
     ax.set_ylim(t0 - datetime.timedelta(days=5),
                 tf + datetime.timedelta(days=5))
@@ -870,8 +1029,8 @@ def test_yearlocator_pytz():
          + datetime.timedelta(i) for i in range(2000)]
     locator = mdates.AutoDateLocator(interval_multiples=True, tz=tz)
     locator.create_dummy_axis()
-    locator.set_view_interval(mdates.date2num(x[0])-1.0,
-                              mdates.date2num(x[-1])+1.0)
+    locator.axis.set_view_interval(mdates.date2num(x[0])-1.0,
+                                   mdates.date2num(x[-1])+1.0)
     t = np.array([733408.208333, 733773.208333, 734138.208333,
                   734503.208333, 734869.208333, 735234.208333, 735599.208333])
     # convert to new epoch from old...
@@ -885,6 +1044,45 @@ def test_yearlocator_pytz():
     assert st == expected
 
 
+def test_YearLocator():
+    def _create_year_locator(date1, date2, **kwargs):
+        locator = mdates.YearLocator(**kwargs)
+        locator.create_dummy_axis()
+        locator.axis.set_view_interval(mdates.date2num(date1),
+                                       mdates.date2num(date2))
+        return locator
+
+    d1 = datetime.datetime(1990, 1, 1)
+    results = ([datetime.timedelta(weeks=52 * 200),
+                {'base': 20, 'month': 1, 'day': 1},
+                ['1980-01-01 00:00:00+00:00', '2000-01-01 00:00:00+00:00',
+                 '2020-01-01 00:00:00+00:00', '2040-01-01 00:00:00+00:00',
+                 '2060-01-01 00:00:00+00:00', '2080-01-01 00:00:00+00:00',
+                 '2100-01-01 00:00:00+00:00', '2120-01-01 00:00:00+00:00',
+                 '2140-01-01 00:00:00+00:00', '2160-01-01 00:00:00+00:00',
+                 '2180-01-01 00:00:00+00:00', '2200-01-01 00:00:00+00:00']
+                ],
+               [datetime.timedelta(weeks=52 * 200),
+                {'base': 20, 'month': 5, 'day': 16},
+                ['1980-05-16 00:00:00+00:00', '2000-05-16 00:00:00+00:00',
+                 '2020-05-16 00:00:00+00:00', '2040-05-16 00:00:00+00:00',
+                 '2060-05-16 00:00:00+00:00', '2080-05-16 00:00:00+00:00',
+                 '2100-05-16 00:00:00+00:00', '2120-05-16 00:00:00+00:00',
+                 '2140-05-16 00:00:00+00:00', '2160-05-16 00:00:00+00:00',
+                 '2180-05-16 00:00:00+00:00', '2200-05-16 00:00:00+00:00']
+                ],
+               [datetime.timedelta(weeks=52 * 5),
+                {'base': 20, 'month': 9, 'day': 25},
+                ['1980-09-25 00:00:00+00:00', '2000-09-25 00:00:00+00:00']
+                ],
+               )
+
+    for delta, arguments, expected in results:
+        d2 = d1 + delta
+        locator = _create_year_locator(d1, d2, **arguments)
+        assert list(map(str, mdates.num2date(locator()))) == expected
+
+
 def test_DayLocator():
     with pytest.raises(ValueError):
         mdates.DayLocator(interval=-1)
@@ -923,12 +1121,15 @@ def test_datetime64_in_list():
 def test_change_epoch():
     date = np.datetime64('2000-01-01')
 
+    # use private method to clear the epoch and allow it to be set...
+    mdates._reset_epoch_test_example()
+    mdates.get_epoch()  # Set default.
+
     with pytest.raises(RuntimeError):
         # this should fail here because there is a sentinel on the epoch
         # if the epoch has been used then it cannot be set.
         mdates.set_epoch('0000-01-01')
 
-    # use private method to clear the epoch and allow it to be set...
     mdates._reset_epoch_test_example()
     mdates.set_epoch('1970-01-01')
     dt = (date - np.datetime64('1970-01-01')).astype('datetime64[D]')
@@ -949,16 +1150,68 @@ def test_change_epoch():
         0.5)
 
 
+def test_warn_notintervals():
+    dates = np.arange('2001-01-10', '2001-03-04', dtype='datetime64[D]')
+    locator = mdates.AutoDateLocator(interval_multiples=False)
+    locator.intervald[3] = [2]
+    locator.create_dummy_axis()
+    locator.axis.set_view_interval(mdates.date2num(dates[0]),
+                                   mdates.date2num(dates[-1]))
+    with pytest.warns(UserWarning, match="AutoDateLocator was unable") as rec:
+        locs = locator()
+
+
+def test_change_converter():
+    plt.rcParams['date.converter'] = 'concise'
+    dates = np.arange('2020-01-01', '2020-05-01', dtype='datetime64[D]')
+    fig, ax = plt.subplots()
+
+    ax.plot(dates, np.arange(len(dates)))
+    fig.canvas.draw()
+    assert ax.get_xticklabels()[0].get_text() == 'Jan'
+    assert ax.get_xticklabels()[1].get_text() == '15'
+
+    plt.rcParams['date.converter'] = 'auto'
+    fig, ax = plt.subplots()
+
+    ax.plot(dates, np.arange(len(dates)))
+    fig.canvas.draw()
+    assert ax.get_xticklabels()[0].get_text() == 'Jan 01 2020'
+    assert ax.get_xticklabels()[1].get_text() == 'Jan 15 2020'
+    with pytest.raises(ValueError):
+        plt.rcParams['date.converter'] = 'boo'
+
+
+def test_change_interval_multiples():
+    plt.rcParams['date.interval_multiples'] = False
+    dates = np.arange('2020-01-10', '2020-05-01', dtype='datetime64[D]')
+    fig, ax = plt.subplots()
+
+    ax.plot(dates, np.arange(len(dates)))
+    fig.canvas.draw()
+    assert ax.get_xticklabels()[0].get_text() == 'Jan 10 2020'
+    assert ax.get_xticklabels()[1].get_text() == 'Jan 24 2020'
+
+    plt.rcParams['date.interval_multiples'] = 'True'
+    fig, ax = plt.subplots()
+
+    ax.plot(dates, np.arange(len(dates)))
+    fig.canvas.draw()
+    assert ax.get_xticklabels()[0].get_text() == 'Jan 15 2020'
+    assert ax.get_xticklabels()[1].get_text() == 'Feb 01 2020'
+
+
 def test_epoch2num():
-    mdates._reset_epoch_test_example()
-    mdates.set_epoch('0000-12-31')
-    assert mdates.epoch2num(86400) == 719164.0
-    assert mdates.num2epoch(719165.0) == 86400 * 2
-    # set back to the default
-    mdates._reset_epoch_test_example()
-    mdates.set_epoch('1970-01-01T00:00:00')
-    assert mdates.epoch2num(86400) == 1.0
-    assert mdates.num2epoch(2.0) == 86400 * 2
+    with _api.suppress_matplotlib_deprecation_warning():
+        mdates._reset_epoch_test_example()
+        mdates.set_epoch('0000-12-31')
+        assert mdates.epoch2num(86400) == 719164.0
+        assert mdates.num2epoch(719165.0) == 86400 * 2
+        # set back to the default
+        mdates._reset_epoch_test_example()
+        mdates.set_epoch('1970-01-01T00:00:00')
+        assert mdates.epoch2num(86400) == 1.0
+        assert mdates.num2epoch(2.0) == 86400 * 2
 
 
 def test_julian2num():
