@@ -1,16 +1,13 @@
-try:
-    from contextlib import nullcontext
-except ImportError:
-    from contextlib import ExitStack as nullcontext  # Py 3.6.
-import re
+from contextlib import nullcontext
 import itertools
+import locale
+import re
 
 import numpy as np
 from numpy.testing import assert_almost_equal, assert_array_equal
 import pytest
 
 import matplotlib as mpl
-from matplotlib import cbook
 import matplotlib.pyplot as plt
 import matplotlib.ticker as mticker
 
@@ -446,21 +443,6 @@ class TestSymmetricalLogLocator:
         assert sym.numticks == 8
 
 
-class TestIndexFormatter:
-    @pytest.mark.parametrize('x, label', [(-2, ''),
-                                          (-1, 'label0'),
-                                          (0, 'label0'),
-                                          (0.5, 'label1'),
-                                          (1, 'label1'),
-                                          (1.5, 'label2'),
-                                          (2, 'label2'),
-                                          (2.5, '')])
-    def test_formatting(self, x, label):
-        with cbook._suppress_matplotlib_deprecation_warning():
-            formatter = mticker.IndexFormatter(['label0', 'label1', 'label2'])
-        assert formatter(x) == label
-
-
 class TestScalarFormatter:
     offset_data = [
         (123, 189, 0),
@@ -529,18 +511,18 @@ class TestScalarFormatter:
     @pytest.mark.parametrize('left, right, offset', offset_data)
     def test_offset_value(self, left, right, offset):
         fig, ax = plt.subplots()
-        formatter = ax.get_xaxis().get_major_formatter()
+        formatter = ax.xaxis.get_major_formatter()
 
         with (pytest.warns(UserWarning, match='Attempting to set identical')
               if left == right else nullcontext()):
             ax.set_xlim(left, right)
-        ax.get_xaxis()._update_ticks()
+        ax.xaxis._update_ticks()
         assert formatter.offset == offset
 
         with (pytest.warns(UserWarning, match='Attempting to set identical')
               if left == right else nullcontext()):
             ax.set_xlim(right, left)
-        ax.get_xaxis()._update_ticks()
+        ax.xaxis._update_ticks()
         assert formatter.offset == offset
 
     @pytest.mark.parametrize('use_offset', use_offset_data)
@@ -549,6 +531,21 @@ class TestScalarFormatter:
             tmp_form = mticker.ScalarFormatter()
             assert use_offset == tmp_form.get_useOffset()
 
+    def test_use_locale(self):
+        conv = locale.localeconv()
+        sep = conv['thousands_sep']
+        if not sep or conv['grouping'][-1:] in ([], [locale.CHAR_MAX]):
+            pytest.skip('Locale does not apply grouping')  # pragma: no cover
+
+        with mpl.rc_context({'axes.formatter.use_locale': True}):
+            tmp_form = mticker.ScalarFormatter()
+            assert tmp_form.get_useLocale()
+
+            tmp_form.create_dummy_axis()
+            tmp_form.axis.set_data_interval(0, 10)
+            tmp_form.set_locs([1, 2, 3])
+            assert sep in tmp_form(1e9)
+
     @pytest.mark.parametrize(
         'sci_type, scilimits, lim, orderOfMag, fewticks', scilimits_data)
     def test_scilimits(self, sci_type, scilimits, lim, orderOfMag, fewticks):
@@ -576,10 +573,22 @@ class TestScalarFormatter:
         # Issue #17624
         sf = mticker.ScalarFormatter()
         sf.create_dummy_axis()
-        sf.set_bounds(0, 10)
+        sf.axis.set_view_interval(0, 10)
         fmt = sf.format_data_short
         assert fmt(data) == expected
 
+    def test_mathtext_ticks(self):
+        mpl.rcParams.update({
+            'font.family': 'serif',
+            'font.serif': 'cmr10',
+            'axes.formatter.use_mathtext': False
+        })
+
+        with pytest.warns(UserWarning, match='cmr10 font should ideally'):
+            fig, ax = plt.subplots()
+            ax.set_xticks([-1, 0, 1])
+            fig.canvas.draw()
+
 
 class FakeAxis:
     """Allow Formatter to be called without having a "full" plot set up."""
@@ -663,7 +672,7 @@ class TestLogFormatterSciNotation:
         (10, 500000, '$\\mathdefault{5\\times10^{5}}$'),
     ]
 
-    @pytest.mark.style('default')
+    @mpl.style.context('default')
     @pytest.mark.parametrize('base, value, expected', test_data)
     def test_basic(self, base, value, expected):
         formatter = mticker.LogFormatterSciNotation(base=base)
@@ -824,7 +833,7 @@ class TestLogFormatter:
         label_test = [fmt(x) != '' for x in minor_tlocs]
         assert label_test == label_expected
 
-    @pytest.mark.style('default')
+    @mpl.style.context('default')
     def test_sublabel(self):
         # test label locator
         fig, ax = plt.subplots()
@@ -869,6 +878,13 @@ class TestLogFormatter:
         temp_lf.axis = FakeAxis()
         assert temp_lf(val) == str(val)
 
+    @pytest.mark.parametrize('val', [1e-323, 2e-323, 10e-323, 11e-323])
+    def test_LogFormatter_call_tiny(self, val):
+        # test coeff computation in __call__
+        temp_lf = mticker.LogFormatter()
+        temp_lf.axis = FakeAxis()
+        temp_lf(val)
+
 
 class TestLogitFormatter:
     @staticmethod
@@ -1113,10 +1129,12 @@ class TestEngFormatter:
         """
         Test the formatting of EngFormatter for various values of the 'places'
         argument, in several cases:
-            0. without a unit symbol but with a (default) space separator;
-            1. with both a unit symbol and a (default) space separator;
-            2. with both a unit symbol and some non default separators;
-            3. without a unit symbol but with some non default separators.
+
+        0. without a unit symbol but with a (default) space separator;
+        1. with both a unit symbol and a (default) space separator;
+        2. with both a unit symbol and some non default separators;
+        3. without a unit symbol but with some non default separators.
+
         Note that cases 2. and 3. are looped over several separator strings.
         """
 
@@ -1350,7 +1368,7 @@ def test_bad_locator_subs(sub):
 
 
 @pytest.mark.parametrize('numticks', [1, 2, 3, 9])
-@pytest.mark.style('default')
+@mpl.style.context('default')
 def test_small_range_loglocator(numticks):
     ll = mticker.LogLocator()
     ll.set_params(numticks=numticks)
