@@ -1,3 +1,5 @@
+import copy
+
 import numpy as np
 from numpy.testing import (assert_allclose, assert_almost_equal,
                            assert_array_equal, assert_array_almost_equal)
@@ -22,7 +24,7 @@ def test_non_affine_caching():
         is_affine = False
 
         def __init__(self, *args, **kwargs):
-            mtransforms.Transform.__init__(self, *args, **kwargs)
+            super().__init__(*args, **kwargs)
             self.raise_on_transform = False
             self.underlying_transform = mtransforms.Affine2D().scale(10, 10)
 
@@ -67,12 +69,13 @@ def test_external_transform_api():
                     mtransforms.Affine2D().scale(10).get_matrix())
 
 
-@image_comparison(['pre_transform_data'],
-                  tol=0.08, remove_text=True, style='mpl20')
+@image_comparison(['pre_transform_data'], remove_text=True, style='mpl20',
+                  tol=0.05)
 def test_pre_transform_plotting():
     # a catch-all for as many as possible plot layouts which handle
     # pre-transforming the data NOTE: The axis range is important in this
     # plot. It should be x10 what the data suggests it should be
+
     ax = plt.axes()
     times10 = mtransforms.Affine2D().scale(10)
 
@@ -91,9 +94,8 @@ def test_pre_transform_plotting():
     u = 2*np.sin(x) + np.cos(y[:, np.newaxis])
     v = np.sin(x) - np.cos(y[:, np.newaxis])
 
-    df = 25. / 30.   # Compatibility factor for old test image
     ax.streamplot(x, y, u, v, transform=times10 + ax.transData,
-                  density=(df, df), linewidth=u**2 + v**2)
+                  linewidth=np.hypot(u, v))
 
     # reduce the vector data down a bit for barb and quiver plotting
     x, y = x[::3], y[::3]
@@ -199,7 +201,7 @@ def test_clipping_of_log():
                                  clip=(0, 0, 100, 100),
                                  simplify=False)
     tpoints, tcodes = zip(*result)
-    assert_allclose(tcodes, path.codes)
+    assert_allclose(tcodes, path.codes[:-1])  # No longer closed.
 
 
 class NonAffineForTest(mtransforms.Transform):
@@ -215,7 +217,7 @@ class NonAffineForTest(mtransforms.Transform):
 
     def __init__(self, real_trans, *args, **kwargs):
         self.real_trans = real_trans
-        mtransforms.Transform.__init__(self, *args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def transform_non_affine(self, values):
         return self.real_trans.transform(values)
@@ -454,6 +456,12 @@ def assert_bbox_eq(bbox1, bbox2):
     assert_array_equal(bbox1.bounds, bbox2.bounds)
 
 
+def test_bbox_frozen_copies_minpos():
+    bbox = mtransforms.Bbox.from_extents(0.0, 0.0, 1.0, 1.0, minpos=1.0)
+    frozen = bbox.frozen()
+    assert_array_equal(frozen.minpos, bbox.minpos)
+
+
 def test_bbox_intersection():
     bbox_from_ext = mtransforms.Bbox.from_extents
     inter = mtransforms.Bbox.intersection
@@ -500,14 +508,8 @@ CompositeGenericTransform(
                     IdentityTransform(),
                     IdentityTransform())),
             CompositeAffine2D(
-                Affine2D(
-                    [[1. 0. 0.]
-                     [0. 1. 0.]
-                     [0. 0. 1.]]),
-                Affine2D(
-                    [[1. 0. 0.]
-                     [0. 1. 0.]
-                     [0. 0. 1.]]))),
+                Affine2D().scale(1.0),
+                Affine2D().scale(1.0))),
         PolarTransform(
             PolarAxesSubplot(0.125,0.1;0.775x0.8),
             use_rmin=True,
@@ -529,14 +531,8 @@ CompositeGenericTransform(
                     TransformedBbox(
                         Bbox(x0=0.0, y0=0.0, x1=6.283185307179586, y1=1.0),
                         CompositeAffine2D(
-                            Affine2D(
-                                [[1. 0. 0.]
-                                 [0. 1. 0.]
-                                 [0. 0. 1.]]),
-                            Affine2D(
-                                [[1. 0. 0.]
-                                 [0. 1. 0.]
-                                 [0. 0. 1.]]))),
+                            Affine2D().scale(1.0),
+                            Affine2D().scale(1.0))),
                     LockableBbox(
                         Bbox(x0=0.0, y0=0.0, x1=6.283185307179586, y1=1.0),
                         [[-- --]
@@ -547,10 +543,7 @@ CompositeGenericTransform(
                 BboxTransformTo(
                     TransformedBbox(
                         Bbox(x0=0.0, y0=0.0, x1=8.0, y1=6.0),
-                        Affine2D(
-                            [[80.  0.  0.]
-                             [ 0. 80.  0.]
-                             [ 0.  0.  1.]])))))))"""
+                        Affine2D().scale(80.0)))))))"""
 
 
 def test_transform_single_point():
@@ -692,3 +685,41 @@ def test_lockable_bbox(locked_element):
     assert getattr(locked, 'locked_' + locked_element) == 3
     for elem in other_elements:
         assert getattr(locked, elem) == getattr(orig, elem)
+
+
+def test_copy():
+    a = mtransforms.Affine2D()
+    b = mtransforms.Affine2D()
+    s = a + b
+    # Updating a dependee should invalidate a copy of the dependent.
+    s.get_matrix()  # resolve it.
+    s1 = copy.copy(s)
+    assert not s._invalid and not s1._invalid
+    a.translate(1, 2)
+    assert s._invalid and s1._invalid
+    assert (s1.get_matrix() == a.get_matrix()).all()
+    # Updating a copy of a dependee shouldn't invalidate a dependent.
+    s.get_matrix()  # resolve it.
+    b1 = copy.copy(b)
+    b1.translate(3, 4)
+    assert not s._invalid
+    assert (s.get_matrix() == a.get_matrix()).all()
+
+
+def test_deepcopy():
+    a = mtransforms.Affine2D()
+    b = mtransforms.Affine2D()
+    s = a + b
+    # Updating a dependee shouldn't invalidate a deepcopy of the dependent.
+    s.get_matrix()  # resolve it.
+    s1 = copy.deepcopy(s)
+    assert not s._invalid and not s1._invalid
+    a.translate(1, 2)
+    assert s._invalid and not s1._invalid
+    assert (s1.get_matrix() == mtransforms.Affine2D().get_matrix()).all()
+    # Updating a deepcopy of a dependee shouldn't invalidate a dependent.
+    s.get_matrix()  # resolve it.
+    b1 = copy.deepcopy(b)
+    b1.translate(3, 4)
+    assert not s._invalid
+    assert (s.get_matrix() == a.get_matrix()).all()
