@@ -1,124 +1,65 @@
 from numbers import Number
+import functools
 
-import matplotlib.axes as maxes
-import matplotlib.ticker as ticker
+import numpy as np
+
+from matplotlib import _api, cbook
 from matplotlib.gridspec import SubplotSpec
 
 from .axes_divider import Size, SubplotDivider, Divider
-from .colorbar import Colorbar
 from .mpl_axes import Axes
 
 
-def _extend_axes_pad(value):
-    # Check whether a list/tuple/array or scalar has been passed
-    ret = value
-    if not hasattr(ret, "__getitem__"):
-        ret = (value, value)
-    return ret
-
-
 def _tick_only(ax, bottom_on, left_on):
     bottom_off = not bottom_on
     left_off = not left_on
-    # [l.set_visible(bottom_off) for l in ax.get_xticklabels()]
-    # [l.set_visible(left_off) for l in ax.get_yticklabels()]
-    # ax.xaxis.label.set_visible(bottom_off)
-    # ax.yaxis.label.set_visible(left_off)
     ax.axis["bottom"].toggle(ticklabels=bottom_off, label=bottom_off)
     ax.axis["left"].toggle(ticklabels=left_off, label=left_off)
 
 
-class CbarAxesBase(object):
-
-    def colorbar(self, mappable, *, locator=None, **kwargs):
-
-        if locator is None:
-            if "ticks" not in kwargs:
-                kwargs["ticks"] = ticker.MaxNLocator(5)
-        if locator is not None:
-            if "ticks" in kwargs:
-                raise ValueError("Either *locator* or *ticks* need" +
-                                 " to be given, not both")
-            else:
-                kwargs["ticks"] = locator
-
-        if self.orientation in ["top", "bottom"]:
-            orientation = "horizontal"
-        else:
-            orientation = "vertical"
-
-        cb = Colorbar(self, mappable, orientation=orientation, **kwargs)
-        self._config_axes()
-
-        def on_changed(m):
-            cb.set_cmap(m.get_cmap())
-            cb.set_clim(m.get_clim())
-            cb.update_bruteforce(m)
-
-        self.cbid = mappable.callbacksSM.connect('changed', on_changed)
-        mappable.colorbar = cb
-
-        self.locator = cb.cbar_axis.get_major_locator()
+class CbarAxesBase:
+    def __init__(self, *args, orientation, **kwargs):
+        self.orientation = orientation
+        self._default_label_on = True
+        self._locator = None  # deprecated.
+        super().__init__(*args, **kwargs)
 
+    def colorbar(self, mappable, *, ticks=None, **kwargs):
+        orientation = (
+            "horizontal" if self.orientation in ["top", "bottom"] else
+            "vertical")
+        cb = self.figure.colorbar(mappable, cax=self, orientation=orientation,
+                                  ticks=ticks, **kwargs)
         return cb
 
-    def _config_axes(self):
-        """Make an axes patch and outline."""
-        ax = self
-        ax.set_navigate(False)
-
-        ax.axis[:].toggle(all=False)
-        b = self._default_label_on
-        ax.axis[self.orientation].toggle(all=b)
-
-        # for axis in ax.axis.values():
-        #     axis.major_ticks.set_visible(False)
-        #     axis.minor_ticks.set_visible(False)
-        #     axis.major_ticklabels.set_visible(False)
-        #     axis.minor_ticklabels.set_visible(False)
-        #     axis.label.set_visible(False)
-
-        # axis = ax.axis[self.orientation]
-        # axis.major_ticks.set_visible(True)
-        # axis.minor_ticks.set_visible(True)
-
-        #axis.major_ticklabels.set_size(
-        #    int(axis.major_ticklabels.get_size()*.9))
-        #axis.major_tick_pad = 3
-
-        # axis.major_ticklabels.set_visible(b)
-        # axis.minor_ticklabels.set_visible(b)
-        # axis.label.set_visible(b)
-
     def toggle_label(self, b):
         self._default_label_on = b
         axis = self.axis[self.orientation]
         axis.toggle(ticklabels=b, label=b)
-        #axis.major_ticklabels.set_visible(b)
-        #axis.minor_ticklabels.set_visible(b)
-        #axis.label.set_visible(b)
-
-
-class CbarAxes(CbarAxesBase, Axes):
-    def __init__(self, *args, orientation, **kwargs):
-        self.orientation = orientation
-        self._default_label_on = True
-        self.locator = None
-        super().__init__(*args, **kwargs)
 
     def cla(self):
+        orientation = self.orientation
         super().cla()
-        self._config_axes()
+        self.orientation = orientation
 
 
-class Grid(object):
+@_api.deprecated("3.5")
+class CbarAxes(CbarAxesBase, Axes):
+    pass
+
+
+_cbaraxes_class_factory = cbook._make_class_factory(CbarAxesBase, "Cbar{}")
+
+
+class Grid:
     """
-    A class that creates a grid of Axes. In matplotlib, the axes
-    location (and size) is specified in the normalized figure
-    coordinates. This may not be ideal for images that needs to be
-    displayed with a given aspect ratio.  For example, displaying
-    images of a same size with some fixed padding between them cannot
-    be easily done in matplotlib. AxesGrid is used in such case.
+    A grid of Axes.
+
+    In Matplotlib, the axes location (and size) is specified in normalized
+    figure coordinates. This may not be ideal for images that needs to be
+    displayed with a given aspect ratio; for example, it is difficult to
+    display multiple images of a same size with some fixed padding between
+    them.  AxesGrid can be used in such case.
     """
 
     _defaultAxesClass = Axes
@@ -129,13 +70,13 @@ class Grid(object):
                  ngrids=None,
                  direction="row",
                  axes_pad=0.02,
-                 add_all=True,
+                 *,
                  share_all=False,
                  share_x=True,
                  share_y=True,
-                 #aspect=True,
                  label_mode="L",
                  axes_class=None,
+                 aspect=False,
                  ):
         """
         Parameters
@@ -145,14 +86,24 @@ class Grid(object):
         rect : (float, float, float, float) or int
             The axes position, as a ``(left, bottom, width, height)`` tuple or
             as a three-digit subplot position code (e.g., "121").
+        nrows_ncols : (int, int)
+            Number of rows and columns in the grid.
+        ngrids : int or None, default: None
+            If not None, only the first *ngrids* axes in the grid are created.
         direction : {"row", "column"}, default: "row"
+            Whether axes are created in row-major ("row by row") or
+            column-major order ("column by column").  This also affects the
+            order in which axes are accessed using indexing (``grid[index]``).
         axes_pad : float or (float, float), default: 0.02
             Padding or (horizontal padding, vertical padding) between axes, in
             inches.
-        add_all : bool, default: True
         share_all : bool, default: False
+            Whether all axes share their x- and y-axis.  Overrides *share_x*
+            and *share_y*.
         share_x : bool, default: True
+            Whether all axes of a column share their x-axis.
         share_y : bool, default: True
+            Whether all axes of a row share their y-axis.
         label_mode : {"L", "1", "all"}, default: "L"
             Determines which axes will get tick labels:
 
@@ -161,8 +112,10 @@ class Grid(object):
             - "1": Only the bottom left axes is labelled.
             - "all": all axes are labelled.
 
-        axes_class : a type that is a subclass of `matplotlib.axes.Axes`, \
-default: None
+        axes_class : subclass of `matplotlib.axes.Axes`, default: None
+        aspect : bool, default: False
+            Whether the axes aspect ratio follows the aspect ratio of the data
+            limits.
         """
         self._nrows, self._ncols = nrows_ncols
 
@@ -174,135 +127,77 @@ default: None
 
         self.ngrids = ngrids
 
-        self._init_axes_pad(axes_pad)
-
-        if direction not in ["column", "row"]:
-            raise Exception("")
+        self._horiz_pad_size, self._vert_pad_size = map(
+            Size.Fixed, np.broadcast_to(axes_pad, 2))
 
+        _api.check_in_list(["column", "row"], direction=direction)
         self._direction = direction
 
         if axes_class is None:
             axes_class = self._defaultAxesClass
-            axes_class_args = {}
-        else:
-            if (isinstance(axes_class, type)
-                    and issubclass(axes_class,
-                                   self._defaultAxesClass.Axes)):
-                axes_class_args = {}
-            else:
-                axes_class, axes_class_args = axes_class
+        elif isinstance(axes_class, (list, tuple)):
+            cls, kwargs = axes_class
+            axes_class = functools.partial(cls, **kwargs)
 
-        self.axes_all = []
-        self.axes_column = [[] for _ in range(self._ncols)]
-        self.axes_row = [[] for _ in range(self._nrows)]
-
-        h = []
-        v = []
-        if isinstance(rect, (str, Number)):
-            self._divider = SubplotDivider(fig, rect, horizontal=h, vertical=v,
-                                           aspect=False)
-        elif isinstance(rect, SubplotSpec):
-            self._divider = SubplotDivider(fig, rect, horizontal=h, vertical=v,
-                                           aspect=False)
+        kw = dict(horizontal=[], vertical=[], aspect=aspect)
+        if isinstance(rect, (str, Number, SubplotSpec)):
+            self._divider = SubplotDivider(fig, rect, **kw)
         elif len(rect) == 3:
-            kw = dict(horizontal=h, vertical=v, aspect=False)
             self._divider = SubplotDivider(fig, *rect, **kw)
         elif len(rect) == 4:
-            self._divider = Divider(fig, rect, horizontal=h, vertical=v,
-                                    aspect=False)
+            self._divider = Divider(fig, rect, **kw)
         else:
             raise Exception("")
 
         rect = self._divider.get_position()
 
-        # reference axes
-        self._column_refax = [None for _ in range(self._ncols)]
-        self._row_refax = [None for _ in range(self._nrows)]
-        self._refax = None
-
+        axes_array = np.full((self._nrows, self._ncols), None, dtype=object)
         for i in range(self.ngrids):
-
             col, row = self._get_col_row(i)
-
             if share_all:
-                sharex = self._refax
-                sharey = self._refax
+                sharex = sharey = axes_array[0, 0]
             else:
-                if share_x:
-                    sharex = self._column_refax[col]
-                else:
-                    sharex = None
-
-                if share_y:
-                    sharey = self._row_refax[row]
-                else:
-                    sharey = None
-
-            ax = axes_class(fig, rect, sharex=sharex, sharey=sharey,
-                            **axes_class_args)
-
-            if share_all:
-                if self._refax is None:
-                    self._refax = ax
-            else:
-                if sharex is None:
-                    self._column_refax[col] = ax
-                if sharey is None:
-                    self._row_refax[row] = ax
-
-            self.axes_all.append(ax)
-            self.axes_column[col].append(ax)
-            self.axes_row[row].append(ax)
-
+                sharex = axes_array[0, col] if share_x else None
+                sharey = axes_array[row, 0] if share_y else None
+            axes_array[row, col] = axes_class(
+                fig, rect, sharex=sharex, sharey=sharey)
+        self.axes_all = axes_array.ravel(
+            order="C" if self._direction == "row" else "F").tolist()
+        self.axes_column = axes_array.T.tolist()
+        self.axes_row = axes_array.tolist()
         self.axes_llc = self.axes_column[0][-1]
 
-        self._update_locators()
+        self._init_locators()
 
-        if add_all:
-            for ax in self.axes_all:
-                fig.add_axes(ax)
+        for ax in self.axes_all:
+            fig.add_axes(ax)
 
         self.set_label_mode(label_mode)
 
-    def _init_axes_pad(self, axes_pad):
-        axes_pad = _extend_axes_pad(axes_pad)
-        self._axes_pad = axes_pad
-
-        self._horiz_pad_size = Size.Fixed(axes_pad[0])
-        self._vert_pad_size = Size.Fixed(axes_pad[1])
-
-    def _update_locators(self):
+    def _init_locators(self):
 
         h = []
-
         h_ax_pos = []
-
-        for _ in self._column_refax:
-            #if h: h.append(Size.Fixed(self._axes_pad))
+        for _ in range(self._ncols):
             if h:
                 h.append(self._horiz_pad_size)
-
             h_ax_pos.append(len(h))
-
             sz = Size.Scaled(1)
             h.append(sz)
 
         v = []
-
         v_ax_pos = []
-        for _ in self._row_refax[::-1]:
-            #if v: v.append(Size.Fixed(self._axes_pad))
+        for _ in range(self._nrows):
             if v:
                 v.append(self._vert_pad_size)
-
             v_ax_pos.append(len(v))
             sz = Size.Scaled(1)
             v.append(sz)
 
         for i in range(self.ngrids):
             col, row = self._get_col_row(i)
-            locator = self._divider.new_locator(nx=h_ax_pos[col],
-                                ny=v_ax_pos[self._nrows - 1 - row])
+            locator = self._divider.new_locator(
+                nx=h_ax_pos[col], ny=v_ax_pos[self._nrows - 1 - row])
             self.axes_all[i].set_axes_locator(locator)
 
         self._divider.set_horizontal(h)
@@ -338,9 +233,6 @@ default: None
         axes_pad : (float, float)
             The padding (horizontal pad, vertical pad) in inches.
         """
-        self._axes_pad = axes_pad
-
-        # These two lines actually differ from ones in _init_axes_pad
         self._horiz_pad_size.fixed_size = axes_pad[0]
         self._vert_pad_size.fixed_size = axes_pad[1]
 
@@ -353,7 +245,8 @@ default: None
         hpad, vpad
             Padding (horizontal pad, vertical pad) in inches.
         """
-        return self._axes_pad
+        return (self._horiz_pad_size.fixed_size,
+                self._vert_pad_size.fixed_size)
 
     def set_aspect(self, aspect):
         """Set the aspect of the SubplotDivider."""
@@ -413,28 +306,13 @@ default: None
     def get_axes_locator(self):
         return self._divider.get_locator()
 
+    @_api.deprecated("3.5")
     def get_vsize_hsize(self):
-
         return self._divider.get_vsize_hsize()
-#         from axes_size import AddList
-
-#         vsize = AddList(self._divider.get_vertical())
-#         hsize = AddList(self._divider.get_horizontal())
-
-#         return vsize, hsize
 
 
 class ImageGrid(Grid):
-    """
-    A class that creates a grid of Axes. In matplotlib, the axes
-    location (and size) is specified in the normalized figure
-    coordinates. This may not be ideal for images that needs to be
-    displayed with a given aspect ratio.  For example, displaying
-    images of a same size with some fixed padding between them cannot
-    be easily done in matplotlib. ImageGrid is used in such case.
-    """
-
-    _defaultCbarAxesClass = CbarAxes
+    # docstring inherited
 
     def __init__(self, fig,
                  rect,
@@ -442,7 +320,7 @@ class ImageGrid(Grid):
                  ngrids=None,
                  direction="row",
                  axes_pad=0.02,
-                 add_all=True,
+                 *,
                  share_all=False,
                  aspect=True,
                  label_mode="L",
@@ -461,13 +339,22 @@ class ImageGrid(Grid):
         rect : (float, float, float, float) or int
             The axes position, as a ``(left, bottom, width, height)`` tuple or
             as a three-digit subplot position code (e.g., "121").
+        nrows_ncols : (int, int)
+            Number of rows and columns in the grid.
+        ngrids : int or None, default: None
+            If not None, only the first *ngrids* axes in the grid are created.
         direction : {"row", "column"}, default: "row"
-        axes_pad : float or (float, float), default: 0.02
+            Whether axes are created in row-major ("row by row") or
+            column-major order ("column by column").  This also affects the
+            order in which axes are accessed using indexing (``grid[index]``).
+        axes_pad : float or (float, float), default: 0.02in
             Padding or (horizontal padding, vertical padding) between axes, in
             inches.
-        add_all : bool, default: True
         share_all : bool, default: False
+            Whether all axes share their x- and y-axis.
         aspect : bool, default: True
+            Whether the axes aspect ratio follows the aspect ratio of the data
+            limits.
         label_mode : {"L", "1", "all"}, default: "L"
             Determines which axes will get tick labels:
 
@@ -476,129 +363,35 @@ class ImageGrid(Grid):
             - "1": Only the bottom left axes is labelled.
             - "all": all axes are labelled.
 
-        cbar_mode : {"each", "single", "edge", None }, default: None
+        cbar_mode : {"each", "single", "edge", None}, default: None
+            Whether to create a colorbar for "each" axes, a "single" colorbar
+            for the entire grid, colorbars only for axes on the "edge"
+            determined by *cbar_location*, or no colorbars.  The colorbars are
+            stored in the :attr:`cbar_axes` attribute.
         cbar_location : {"left", "right", "bottom", "top"}, default: "right"
         cbar_pad : float, default: None
+            Padding between the image axes and the colorbar axes.
         cbar_size : size specification (see `.Size.from_any`), default: "5%"
+            Colorbar size.
         cbar_set_cax : bool, default: True
             If True, each axes in the grid has a *cax* attribute that is bound
             to associated *cbar_axes*.
-        axes_class : a type that is a subclass of `matplotlib.axes.Axes`, \
-default: None
+        axes_class : subclass of `matplotlib.axes.Axes`, default: None
         """
-        self._nrows, self._ncols = nrows_ncols
-
-        if ngrids is None:
-            ngrids = self._nrows * self._ncols
-        else:
-            if not 0 < ngrids <= self._nrows * self._ncols:
-                raise Exception
-
-        self.ngrids = ngrids
-
-        axes_pad = _extend_axes_pad(axes_pad)
-        self._axes_pad = axes_pad
-
         self._colorbar_mode = cbar_mode
         self._colorbar_location = cbar_location
-        if cbar_pad is None:
-            # horizontal or vertical arrangement?
-            if cbar_location in ("left", "right"):
-                self._colorbar_pad = axes_pad[0]
-            else:
-                self._colorbar_pad = axes_pad[1]
-        else:
-            self._colorbar_pad = cbar_pad
-
+        self._colorbar_pad = cbar_pad
         self._colorbar_size = cbar_size
+        # The colorbar axes are created in _init_locators().
 
-        self._init_axes_pad(axes_pad)
+        super().__init__(
+            fig, rect, nrows_ncols, ngrids,
+            direction=direction, axes_pad=axes_pad,
+            share_all=share_all, share_x=True, share_y=True, aspect=aspect,
+            label_mode=label_mode, axes_class=axes_class)
 
-        if direction not in ["column", "row"]:
-            raise Exception("")
-
-        self._direction = direction
-
-        if axes_class is None:
-            axes_class = self._defaultAxesClass
-            axes_class_args = {}
-        else:
-            if isinstance(axes_class, maxes.Axes):
-                axes_class_args = {}
-            else:
-                axes_class, axes_class_args = axes_class
-
-        self.axes_all = []
-        self.axes_column = [[] for _ in range(self._ncols)]
-        self.axes_row = [[] for _ in range(self._nrows)]
-
-        self.cbar_axes = []
-
-        h = []
-        v = []
-        if isinstance(rect, (str, Number)):
-            self._divider = SubplotDivider(fig, rect, horizontal=h, vertical=v,
-                                           aspect=aspect)
-        elif isinstance(rect, SubplotSpec):
-            self._divider = SubplotDivider(fig, rect, horizontal=h, vertical=v,
-                                           aspect=aspect)
-        elif len(rect) == 3:
-            kw = dict(horizontal=h, vertical=v, aspect=aspect)
-            self._divider = SubplotDivider(fig, *rect, **kw)
-        elif len(rect) == 4:
-            self._divider = Divider(fig, rect, horizontal=h, vertical=v,
-                                    aspect=aspect)
-        else:
-            raise Exception("")
-
-        rect = self._divider.get_position()
-
-        # reference axes
-        self._column_refax = [None for _ in range(self._ncols)]
-        self._row_refax = [None for _ in range(self._nrows)]
-        self._refax = None
-
-        for i in range(self.ngrids):
-
-            col, row = self._get_col_row(i)
-
-            if share_all:
-                if self.axes_all:
-                    sharex = self.axes_all[0]
-                    sharey = self.axes_all[0]
-                else:
-                    sharex = None
-                    sharey = None
-            else:
-                sharex = self._column_refax[col]
-                sharey = self._row_refax[row]
-
-            ax = axes_class(fig, rect, sharex=sharex, sharey=sharey,
-                            **axes_class_args)
-
-            self.axes_all.append(ax)
-            self.axes_column[col].append(ax)
-            self.axes_row[row].append(ax)
-
-            if share_all:
-                if self._refax is None:
-                    self._refax = ax
-            if sharex is None:
-                self._column_refax[col] = ax
-            if sharey is None:
-                self._row_refax[row] = ax
-
-            cax = self._defaultCbarAxesClass(fig, rect,
-                                        orientation=self._colorbar_location)
-            self.cbar_axes.append(cax)
-
-        self.axes_llc = self.axes_column[0][-1]
-
-        self._update_locators()
-
-        if add_all:
-            for ax in self.axes_all+self.cbar_axes:
-                fig.add_axes(ax)
+        for ax in self.cbar_axes:
+            fig.add_axes(ax)
 
         if cbar_set_cax:
             if self._colorbar_mode == "single":
@@ -615,26 +408,37 @@ default: None
                 for ax, cax in zip(self.axes_all, self.cbar_axes):
                     ax.cax = cax
 
-        self.set_label_mode(label_mode)
+    def _init_locators(self):
+        # Slightly abusing this method to inject colorbar creation into init.
 
-    def _update_locators(self):
+        if self._colorbar_pad is None:
+            # horizontal or vertical arrangement?
+            if self._colorbar_location in ("left", "right"):
+                self._colorbar_pad = self._horiz_pad_size.fixed_size
+            else:
+                self._colorbar_pad = self._vert_pad_size.fixed_size
+        self.cbar_axes = [
+            _cbaraxes_class_factory(self._defaultAxesClass)(
+                self.axes_all[0].figure, self._divider.get_position(),
+                orientation=self._colorbar_location)
+            for _ in range(self.ngrids)]
+
+        cb_mode = self._colorbar_mode
+        cb_location = self._colorbar_location
 
         h = []
         v = []
 
         h_ax_pos = []
         h_cb_pos = []
-        if (self._colorbar_mode == "single" and
-             self._colorbar_location in ('left', 'bottom')):
-            if self._colorbar_location == "left":
-                #sz = Size.Fraction(Size.AxesX(self.axes_llc), self._nrows)
-                sz = Size.Fraction(self._nrows, Size.AxesX(self.axes_llc))
+        if cb_mode == "single" and cb_location in ("left", "bottom"):
+            if cb_location == "left":
+                sz = self._nrows * Size.AxesX(self.axes_llc)
                 h.append(Size.from_any(self._colorbar_size, sz))
                 h.append(Size.from_any(self._colorbar_pad, sz))
                 locator = self._divider.new_locator(nx=0, ny=0, ny1=-1)
-            elif self._colorbar_location == "bottom":
-                #sz = Size.Fraction(Size.AxesY(self.axes_llc), self._ncols)
-                sz = Size.Fraction(self._ncols, Size.AxesY(self.axes_llc))
+            elif cb_location == "bottom":
+                sz = self._ncols * Size.AxesY(self.axes_llc)
                 v.append(Size.from_any(self._colorbar_size, sz))
                 v.append(Size.from_any(self._colorbar_pad, sz))
                 locator = self._divider.new_locator(nx=0, nx1=-1, ny=0)
@@ -645,7 +449,7 @@ default: None
 
         for col, ax in enumerate(self.axes_row[0]):
             if h:
-                h.append(self._horiz_pad_size)  # Size.Fixed(self._axes_pad))
+                h.append(self._horiz_pad_size)
 
             if ax:
                 sz = Size.AxesX(ax, aspect="axes", ref_ax=self.axes_all[0])
@@ -653,21 +457,19 @@ default: None
                 sz = Size.AxesX(self.axes_all[0],
                                 aspect="axes", ref_ax=self.axes_all[0])
 
-            if (self._colorbar_mode == "each" or
-                    (self._colorbar_mode == 'edge' and
-                        col == 0)) and self._colorbar_location == "left":
+            if (cb_location == "left"
+                    and (cb_mode == "each"
+                         or (cb_mode == "edge" and col == 0))):
                 h_cb_pos.append(len(h))
                 h.append(Size.from_any(self._colorbar_size, sz))
                 h.append(Size.from_any(self._colorbar_pad, sz))
 
             h_ax_pos.append(len(h))
-
             h.append(sz)
 
-            if ((self._colorbar_mode == "each" or
-                    (self._colorbar_mode == 'edge' and
-                        col == self._ncols - 1)) and
-                    self._colorbar_location == "right"):
+            if (cb_location == "right"
+                    and (cb_mode == "each"
+                         or (cb_mode == "edge" and col == self._ncols - 1))):
                 h.append(Size.from_any(self._colorbar_pad, sz))
                 h_cb_pos.append(len(h))
                 h.append(Size.from_any(self._colorbar_size, sz))
@@ -676,7 +478,7 @@ default: None
         v_cb_pos = []
         for row, ax in enumerate(self.axes_column[0][::-1]):
             if v:
-                v.append(self._vert_pad_size)  # Size.Fixed(self._axes_pad))
+                v.append(self._vert_pad_size)
 
             if ax:
                 sz = Size.AxesY(ax, aspect="axes", ref_ax=self.axes_all[0])
@@ -684,9 +486,9 @@ default: None
                 sz = Size.AxesY(self.axes_all[0],
                                 aspect="axes", ref_ax=self.axes_all[0])
 
-            if (self._colorbar_mode == "each" or
-                    (self._colorbar_mode == 'edge' and
-                        row == 0)) and self._colorbar_location == "bottom":
+            if (cb_location == "bottom"
+                    and (cb_mode == "each"
+                         or (cb_mode == "edge" and row == 0))):
                 v_cb_pos.append(len(v))
                 v.append(Size.from_any(self._colorbar_size, sz))
                 v.append(Size.from_any(self._colorbar_pad, sz))
@@ -694,69 +496,62 @@ default: None
             v_ax_pos.append(len(v))
             v.append(sz)
 
-            if ((self._colorbar_mode == "each" or
-                    (self._colorbar_mode == 'edge' and
-                        row == self._nrows - 1)) and
-                        self._colorbar_location == "top"):
+            if (cb_location == "top"
+                    and (cb_mode == "each"
+                         or (cb_mode == "edge" and row == self._nrows - 1))):
                 v.append(Size.from_any(self._colorbar_pad, sz))
                 v_cb_pos.append(len(v))
                 v.append(Size.from_any(self._colorbar_size, sz))
 
         for i in range(self.ngrids):
             col, row = self._get_col_row(i)
-            #locator = self._divider.new_locator(nx=4*col,
-            #                                    ny=2*(self._nrows - row - 1))
             locator = self._divider.new_locator(nx=h_ax_pos[col],
                                                 ny=v_ax_pos[self._nrows-1-row])
             self.axes_all[i].set_axes_locator(locator)
 
-            if self._colorbar_mode == "each":
-                if self._colorbar_location in ("right", "left"):
+            if cb_mode == "each":
+                if cb_location in ("right", "left"):
                     locator = self._divider.new_locator(
                         nx=h_cb_pos[col], ny=v_ax_pos[self._nrows - 1 - row])
 
-                elif self._colorbar_location in ("top", "bottom"):
+                elif cb_location in ("top", "bottom"):
                     locator = self._divider.new_locator(
                         nx=h_ax_pos[col], ny=v_cb_pos[self._nrows - 1 - row])
 
                 self.cbar_axes[i].set_axes_locator(locator)
-            elif self._colorbar_mode == 'edge':
-                if ((self._colorbar_location == 'left' and col == 0) or
-                        (self._colorbar_location == 'right'
-                         and col == self._ncols-1)):
+            elif cb_mode == "edge":
+                if (cb_location == "left" and col == 0
+                        or cb_location == "right" and col == self._ncols - 1):
                     locator = self._divider.new_locator(
                         nx=h_cb_pos[0], ny=v_ax_pos[self._nrows - 1 - row])
                     self.cbar_axes[row].set_axes_locator(locator)
-                elif ((self._colorbar_location == 'bottom' and
-                       row == self._nrows - 1) or
-                        (self._colorbar_location == 'top' and row == 0)):
+                elif (cb_location == "bottom" and row == self._nrows - 1
+                      or cb_location == "top" and row == 0):
                     locator = self._divider.new_locator(nx=h_ax_pos[col],
                                                         ny=v_cb_pos[0])
                     self.cbar_axes[col].set_axes_locator(locator)
 
-        if self._colorbar_mode == "single":
-            if self._colorbar_location == "right":
-                #sz = Size.Fraction(Size.AxesX(self.axes_llc), self._nrows)
-                sz = Size.Fraction(self._nrows, Size.AxesX(self.axes_llc))
+        if cb_mode == "single":
+            if cb_location == "right":
+                sz = self._nrows * Size.AxesX(self.axes_llc)
                 h.append(Size.from_any(self._colorbar_pad, sz))
                 h.append(Size.from_any(self._colorbar_size, sz))
                 locator = self._divider.new_locator(nx=-2, ny=0, ny1=-1)
-            elif self._colorbar_location == "top":
-                #sz = Size.Fraction(Size.AxesY(self.axes_llc), self._ncols)
-                sz = Size.Fraction(self._ncols, Size.AxesY(self.axes_llc))
+            elif cb_location == "top":
+                sz = self._ncols * Size.AxesY(self.axes_llc)
                 v.append(Size.from_any(self._colorbar_pad, sz))
                 v.append(Size.from_any(self._colorbar_size, sz))
                 locator = self._divider.new_locator(nx=0, nx1=-1, ny=-2)
-            if self._colorbar_location in ("right", "top"):
+            if cb_location in ("right", "top"):
                 for i in range(self.ngrids):
                     self.cbar_axes[i].set_visible(False)
                 self.cbar_axes[0].set_axes_locator(locator)
                 self.cbar_axes[0].set_visible(True)
-        elif self._colorbar_mode == "each":
+        elif cb_mode == "each":
             for i in range(self.ngrids):
                 self.cbar_axes[i].set_visible(True)
-        elif self._colorbar_mode == "edge":
-            if self._colorbar_location in ('right', 'left'):
+        elif cb_mode == "edge":
+            if cb_location in ("right", "left"):
                 count = self._nrows
             else:
                 count = self._ncols
