@@ -28,9 +28,11 @@ PyObject *convert_polygon_vector(std::vector<Polygon> &polygons)
     return pyresult;
 }
 
-const char *Py_point_in_path__doc__ = "point_in_path(x, y, radius, path, trans)";
+const char *Py_point_in_path__doc__ =
+    "point_in_path(x, y, radius, path, trans)\n"
+    "--\n\n";
 
-static PyObject *Py_point_in_path(PyObject *self, PyObject *args, PyObject *kwds)
+static PyObject *Py_point_in_path(PyObject *self, PyObject *args)
 {
     double x, y, r;
     py::PathIterator path;
@@ -58,9 +60,11 @@ static PyObject *Py_point_in_path(PyObject *self, PyObject *args, PyObject *kwds
     }
 }
 
-const char *Py_points_in_path__doc__ = "points_in_path(points, radius, path, trans)";
+const char *Py_points_in_path__doc__ =
+    "points_in_path(points, radius, path, trans)\n"
+    "--\n\n";
 
-static PyObject *Py_points_in_path(PyObject *self, PyObject *args, PyObject *kwds)
+static PyObject *Py_points_in_path(PyObject *self, PyObject *args)
 {
     numpy::array_view<const double, 2> points;
     double r;
@@ -87,9 +91,11 @@ static PyObject *Py_points_in_path(PyObject *self, PyObject *args, PyObject *kwd
     return results.pyobj();
 }
 
-const char *Py_point_on_path__doc__ = "point_on_path(x, y, radius, path, trans)";
+const char *Py_point_on_path__doc__ =
+    "point_on_path(x, y, radius, path, trans)\n"
+    "--\n\n";
 
-static PyObject *Py_point_on_path(PyObject *self, PyObject *args, PyObject *kwds)
+static PyObject *Py_point_on_path(PyObject *self, PyObject *args)
 {
     double x, y, r;
     py::PathIterator path;
@@ -117,9 +123,11 @@ static PyObject *Py_point_on_path(PyObject *self, PyObject *args, PyObject *kwds
     }
 }
 
-const char *Py_points_on_path__doc__ = "points_on_path(points, radius, path, trans)";
+const char *Py_points_on_path__doc__ =
+    "points_on_path(points, radius, path, trans)\n"
+    "--\n\n";
 
-static PyObject *Py_points_on_path(PyObject *self, PyObject *args, PyObject *kwds)
+static PyObject *Py_points_on_path(PyObject *self, PyObject *args)
 {
     numpy::array_view<const double, 2> points;
     double r;
@@ -146,9 +154,11 @@ static PyObject *Py_points_on_path(PyObject *self, PyObject *args, PyObject *kwd
     return results.pyobj();
 }
 
-const char *Py_get_path_extents__doc__ = "get_path_extents(path, trans)";
+const char *Py_get_path_extents__doc__ =
+    "get_path_extents(path, trans)\n"
+    "--\n\n";
 
-static PyObject *Py_get_path_extents(PyObject *self, PyObject *args, PyObject *kwds)
+static PyObject *Py_get_path_extents(PyObject *self, PyObject *args)
 {
     py::PathIterator path;
     agg::trans_affine trans;
@@ -174,9 +184,10 @@ static PyObject *Py_get_path_extents(PyObject *self, PyObject *args, PyObject *k
 }
 
 const char *Py_update_path_extents__doc__ =
-    "update_path_extents(path, trans, rect, minpos, ignore)";
+    "update_path_extents(path, trans, rect, minpos, ignore)\n"
+    "--\n\n";
 
-static PyObject *Py_update_path_extents(PyObject *self, PyObject *args, PyObject *kwds)
+static PyObject *Py_update_path_extents(PyObject *self, PyObject *args)
 {
     py::PathIterator path;
     agg::trans_affine trans;
@@ -250,22 +261,26 @@ static PyObject *Py_update_path_extents(PyObject *self, PyObject *args, PyObject
         "NNi", outextents.pyobj(), outminpos.pyobj(), changed);
 }
 
-const char *Py_get_path_collection_extents__doc__ = "get_path_collection_extents(";
+const char *Py_get_path_collection_extents__doc__ =
+    "get_path_collection_extents("
+    "master_transform, paths, transforms, offsets, offset_transform)\n"
+    "--\n\n";
 
-static PyObject *Py_get_path_collection_extents(PyObject *self, PyObject *args, PyObject *kwds)
+static PyObject *Py_get_path_collection_extents(PyObject *self, PyObject *args)
 {
     agg::trans_affine master_transform;
-    PyObject *pathsobj;
+    py::PathGenerator paths;
     numpy::array_view<const double, 3> transforms;
     numpy::array_view<const double, 2> offsets;
     agg::trans_affine offset_trans;
     extent_limits e;
 
     if (!PyArg_ParseTuple(args,
-                          "O&OO&O&O&:get_path_collection_extents",
+                          "O&O&O&O&O&:get_path_collection_extents",
                           &convert_trans_affine,
                           &master_transform,
-                          &pathsobj,
+                          &convert_pathgen,
+                          &paths,
                           &convert_transforms,
                           &transforms,
                           &convert_points,
@@ -275,18 +290,9 @@ static PyObject *Py_get_path_collection_extents(PyObject *self, PyObject *args,
         return NULL;
     }
 
-    try
-    {
-        py::PathGenerator paths(pathsobj);
-
-        CALL_CPP("get_path_collection_extents",
-                 (get_path_collection_extents(
-                     master_transform, paths, transforms, offsets, offset_trans, e)));
-    }
-    catch (const py::exception &)
-    {
-        return NULL;
-    }
+    CALL_CPP("get_path_collection_extents",
+             (get_path_collection_extents(
+                 master_transform, paths, transforms, offsets, offset_trans, e)));
 
     npy_intp dims[] = { 2, 2 };
     numpy::array_view<double, 2> extents(dims);
@@ -295,33 +301,41 @@ static PyObject *Py_get_path_collection_extents(PyObject *self, PyObject *args,
     extents(1, 0) = e.x1;
     extents(1, 1) = e.y1;
 
-    return extents.pyobj();
+    npy_intp minposdims[] = { 2 };
+    numpy::array_view<double, 1> minpos(minposdims);
+    minpos(0) = e.xm;
+    minpos(1) = e.ym;
+
+    return Py_BuildValue("NN", extents.pyobj(), minpos.pyobj());
 }
 
 const char *Py_point_in_path_collection__doc__ =
-    "point_in_path_collection(x, y, radius, master_transform, paths, transforms, offsets, "
-    "offset_trans, filled, offset_position)";
+    "point_in_path_collection("
+    "x, y, radius, master_transform, paths, transforms, offsets, "
+    "offset_trans, filled, offset_position)\n"
+    "--\n\n";
 
-static PyObject *Py_point_in_path_collection(PyObject *self, PyObject *args, PyObject *kwds)
+static PyObject *Py_point_in_path_collection(PyObject *self, PyObject *args)
 {
     double x, y, radius;
     agg::trans_affine master_transform;
-    PyObject *pathsobj;
+    py::PathGenerator paths;
     numpy::array_view<const double, 3> transforms;
     numpy::array_view<const double, 2> offsets;
     agg::trans_affine offset_trans;
     bool filled;
-    e_offset_position offset_position;
+    PyObject *offset_position; // no longer used
     std::vector<int> result;
 
     if (!PyArg_ParseTuple(args,
-                          "dddO&OO&O&O&O&O&:point_in_path_collection",
+                          "dddO&O&O&O&O&O&O:point_in_path_collection",
                           &x,
                           &y,
                           &radius,
                           &convert_trans_affine,
                           &master_transform,
-                          &pathsobj,
+                          &convert_pathgen,
+                          &paths,
                           &convert_transforms,
                           &transforms,
                           &convert_points,
@@ -330,32 +344,21 @@ static PyObject *Py_point_in_path_collection(PyObject *self, PyObject *args, PyO
                           &offset_trans,
                           &convert_bool,
                           &filled,
-                          &convert_offset_position,
                           &offset_position)) {
         return NULL;
     }
 
-    try
-    {
-        py::PathGenerator paths(pathsobj);
-
-        CALL_CPP("point_in_path_collection",
-                 (point_in_path_collection(x,
-                                           y,
-                                           radius,
-                                           master_transform,
-                                           paths,
-                                           transforms,
-                                           offsets,
-                                           offset_trans,
-                                           filled,
-                                           offset_position,
-                                           result)));
-    }
-    catch (const py::exception &)
-    {
-        return NULL;
-    }
+    CALL_CPP("point_in_path_collection",
+             (point_in_path_collection(x,
+                                       y,
+                                       radius,
+                                       master_transform,
+                                       paths,
+                                       transforms,
+                                       offsets,
+                                       offset_trans,
+                                       filled,
+                                       result)));
 
     npy_intp dims[] = {(npy_intp)result.size() };
     numpy::array_view<int, 1> pyresult(dims);
@@ -365,9 +368,11 @@ static PyObject *Py_point_in_path_collection(PyObject *self, PyObject *args, PyO
     return pyresult.pyobj();
 }
 
-const char *Py_path_in_path__doc__ = "path_in_path(path_a, trans_a, path_b, trans_b)";
+const char *Py_path_in_path__doc__ =
+    "path_in_path(path_a, trans_a, path_b, trans_b)\n"
+    "--\n\n";
 
-static PyObject *Py_path_in_path(PyObject *self, PyObject *args, PyObject *kwds)
+static PyObject *Py_path_in_path(PyObject *self, PyObject *args)
 {
     py::PathIterator a;
     agg::trans_affine atrans;
@@ -397,9 +402,11 @@ static PyObject *Py_path_in_path(PyObject *self, PyObject *args, PyObject *kwds)
     }
 }
 
-const char *Py_clip_path_to_rect__doc__ = "clip_path_to_rect(path, rect, inside)";
+const char *Py_clip_path_to_rect__doc__ =
+    "clip_path_to_rect(path, rect, inside)\n"
+    "--\n\n";
 
-static PyObject *Py_clip_path_to_rect(PyObject *self, PyObject *args, PyObject *kwds)
+static PyObject *Py_clip_path_to_rect(PyObject *self, PyObject *args)
 {
     py::PathIterator path;
     agg::rect_d rect;
@@ -422,9 +429,11 @@ static PyObject *Py_clip_path_to_rect(PyObject *self, PyObject *args, PyObject *
     return convert_polygon_vector(result);
 }
 
-const char *Py_affine_transform__doc__ = "affine_transform(points, trans)";
+const char *Py_affine_transform__doc__ =
+    "affine_transform(points, trans)\n"
+    "--\n\n";
 
-static PyObject *Py_affine_transform(PyObject *self, PyObject *args, PyObject *kwds)
+static PyObject *Py_affine_transform(PyObject *self, PyObject *args)
 {
     PyObject *vertices_obj;
     agg::trans_affine trans;
@@ -444,24 +453,28 @@ static PyObject *Py_affine_transform(PyObject *self, PyObject *args, PyObject *k
 
     if (PyArray_NDIM(vertices_arr) == 2) {
         numpy::array_view<double, 2> vertices(vertices_arr);
+        Py_DECREF(vertices_arr);
+
         npy_intp dims[] = { (npy_intp)vertices.size(), 2 };
         numpy::array_view<double, 2> result(dims);
         CALL_CPP("affine_transform", (affine_transform_2d(vertices, trans, result)));
-        Py_DECREF(vertices_arr);
         return result.pyobj();
     } else { // PyArray_NDIM(vertices_arr) == 1
         numpy::array_view<double, 1> vertices(vertices_arr);
+        Py_DECREF(vertices_arr);
+
         npy_intp dims[] = { (npy_intp)vertices.size() };
         numpy::array_view<double, 1> result(dims);
         CALL_CPP("affine_transform", (affine_transform_1d(vertices, trans, result)));
-        Py_DECREF(vertices_arr);
         return result.pyobj();
     }
 }
 
-const char *Py_count_bboxes_overlapping_bbox__doc__ = "count_bboxes_overlapping_bbox(bbox, bboxes)";
+const char *Py_count_bboxes_overlapping_bbox__doc__ =
+    "count_bboxes_overlapping_bbox(bbox, bboxes)\n"
+    "--\n\n";
 
-static PyObject *Py_count_bboxes_overlapping_bbox(PyObject *self, PyObject *args, PyObject *kwds)
+static PyObject *Py_count_bboxes_overlapping_bbox(PyObject *self, PyObject *args)
 {
     agg::rect_d bbox;
     numpy::array_view<const double, 3> bboxes;
@@ -482,7 +495,9 @@ static PyObject *Py_count_bboxes_overlapping_bbox(PyObject *self, PyObject *args
     return PyLong_FromLong(result);
 }
 
-const char *Py_path_intersects_path__doc__ = "path_intersects_path(path1, path2, filled=False)";
+const char *Py_path_intersects_path__doc__ =
+    "path_intersects_path(path1, path2, filled=False)\n"
+    "--\n\n";
 
 static PyObject *Py_path_intersects_path(PyObject *self, PyObject *args, PyObject *kwds)
 {
@@ -525,7 +540,10 @@ static PyObject *Py_path_intersects_path(PyObject *self, PyObject *args, PyObjec
     }
 }
 
-const char *Py_path_intersects_rectangle__doc__ = "path_intersects_rectangle(path, rect_x1, rect_y1, rect_x2, rect_y2, filled=False)";
+const char *Py_path_intersects_rectangle__doc__ =
+    "path_intersects_rectangle("
+    "path, rect_x1, rect_y1, rect_x2, rect_y2, filled=False)\n"
+    "--\n\n";
 
 static PyObject *Py_path_intersects_rectangle(PyObject *self, PyObject *args, PyObject *kwds)
 {
@@ -560,7 +578,8 @@ static PyObject *Py_path_intersects_rectangle(PyObject *self, PyObject *args, Py
 }
 
 const char *Py_convert_path_to_polygons__doc__ =
-    "convert_path_to_polygons(path, trans, width=0, height=0)";
+    "convert_path_to_polygons(path, trans, width=0, height=0)\n"
+    "--\n\n";
 
 static PyObject *Py_convert_path_to_polygons(PyObject *self, PyObject *args, PyObject *kwds)
 {
@@ -592,10 +611,12 @@ static PyObject *Py_convert_path_to_polygons(PyObject *self, PyObject *args, PyO
 }
 
 const char *Py_cleanup_path__doc__ =
-    "cleanup_path(path, trans, remove_nans, clip_rect, snap_mode, stroke_width, simplify, "
-    "return_curves, sketch)";
+    "cleanup_path("
+    "path, trans, remove_nans, clip_rect, snap_mode, stroke_width, simplify, "
+    "return_curves, sketch)\n"
+    "--\n\n";
 
-static PyObject *Py_cleanup_path(PyObject *self, PyObject *args, PyObject *kwds)
+static PyObject *Py_cleanup_path(PyObject *self, PyObject *args)
 {
     py::PathIterator path;
     agg::trans_affine trans;
@@ -672,10 +693,37 @@ static PyObject *Py_cleanup_path(PyObject *self, PyObject *args, PyObject *kwds)
     return Py_BuildValue("NN", pyvertices.pyobj(), pycodes.pyobj());
 }
 
-const char *Py_convert_to_string__doc__ = "convert_to_string(path, trans, "
-    "clip_rect, simplify, sketch, precision, codes, postfix)";
+const char *Py_convert_to_string__doc__ =
+    "convert_to_string("
+    "path, trans, clip_rect, simplify, sketch, precision, codes, postfix)\n"
+    "--\n\n"
+    "Convert *path* to a bytestring.\n"
+    "\n"
+    "The first five parameters (up to *sketch*) are interpreted as in \n"
+    "`.cleanup_path`.  The following ones are detailed below.\n"
+    "\n"
+    "Parameters\n"
+    "----------\n"
+    "path : Path\n"
+    "trans : Transform or None\n"
+    "clip_rect : sequence of 4 floats, or None\n"
+    "simplify : bool\n"
+    "sketch : tuple of 3 floats, or None\n"
+    "precision : int\n"
+    "    The precision used to \"%.*f\"-format the values.  Trailing zeros\n"
+    "    and decimal points are always removed.  (precision=-1 is a special \n"
+    "    case used to implement ttconv-back-compatible conversion.)\n"
+    "codes : sequence of 5 bytestrings\n"
+    "    The bytes representation of each opcode (MOVETO, LINETO, CURVE3,\n"
+    "    CURVE4, CLOSEPOLY), in that order.  If the bytes for CURVE3 is\n"
+    "    empty, quad segments are automatically converted to cubic ones\n"
+    "    (this is used by backends such as pdf and ps, which do not support\n"
+    "    quads).\n"
+    "postfix : bool\n"
+    "    Whether the opcode comes after the values (True) or before (False).\n"
+    ;
 
-static PyObject *Py_convert_to_string(PyObject *self, PyObject *args, PyObject *kwds)
+static PyObject *Py_convert_to_string(PyObject *self, PyObject *args)
 {
     py::PathIterator path;
     agg::trans_affine trans;
@@ -735,8 +783,10 @@ static PyObject *Py_convert_to_string(PyObject *self, PyObject *args, PyObject *
 }
 
 
-const char *Py_is_sorted__doc__ = "is_sorted(array)\n\n"
-    "Returns True if 1-D array is monotonically increasing, ignoring NaNs\n";
+const char *Py_is_sorted__doc__ =
+    "is_sorted(array)\n"
+    "--\n\n"
+    "Return whether the 1D *array* is monotonically increasing, ignoring NaNs.\n";
 
 static PyObject *Py_is_sorted(PyObject *self, PyObject *obj)
 {
@@ -842,31 +892,15 @@ static PyMethodDef module_functions[] = {
 };
 
 static struct PyModuleDef moduledef = {
-    PyModuleDef_HEAD_INIT,
-    "_path",
-    NULL,
-    0,
-    module_functions,
-    NULL,
-    NULL,
-    NULL,
-    NULL
+    PyModuleDef_HEAD_INIT, "_path", NULL, 0, module_functions
 };
 
 #pragma GCC visibility push(default)
 
 PyMODINIT_FUNC PyInit__path(void)
 {
-    PyObject *m;
-    m = PyModule_Create(&moduledef);
-
-    if (m == NULL) {
-        return NULL;
-    }
-
     import_array();
-
-    return m;
+    return PyModule_Create(&moduledef);
 }
 
 #pragma GCC visibility pop
