@@ -1,28 +1,23 @@
 r"""
 *************************
-Text rendering With LaTeX
+Text rendering with LaTeX
 *************************
 
-Rendering text with LaTeX in Matplotlib.
-
-Matplotlib has the option to use LaTeX to manage all text layout.  This
-option is available with the following backends:
-
-* Agg
-* PS
-* PDF
-
-The LaTeX option is activated by setting ``text.usetex : True`` in your rc
-settings.  Text handling with matplotlib's LaTeX support is slower than
-matplotlib's very capable :doc:`mathtext </tutorials/text/mathtext>`, but is
-more flexible, since different LaTeX packages (font packages, math packages,
+Matplotlib can use LaTeX to render text.  This is activated by setting
+``text.usetex : True`` in your rcParams, or by setting the ``usetex`` property
+to True on individual `.Text` objects.  Text handling through LaTeX is slower
+than Matplotlib's very capable :doc:`mathtext </tutorials/text/mathtext>`, but
+is more flexible, since different LaTeX packages (font packages, math packages,
 etc.) can be used. The results can be striking, especially when you take care
 to use the same fonts in your figures as in the main document.
 
-Matplotlib's LaTeX support requires a working LaTeX_ installation, dvipng_
-(which may be included with your LaTeX installation), and Ghostscript_
-(GPL Ghostscript 9.0 or later is required). The executables for these
-external dependencies must all be located on your :envvar:`PATH`.
+Matplotlib's LaTeX support requires a working LaTeX_ installation.  For
+the \*Agg backends, dvipng_ is additionally required; for the PS backend,
+PSfrag_, dvips_ and Ghostscript_ are additionally required.  For the PDF
+and SVG backends, if LuaTeX is present, it will be used to speed up some
+post-processing steps, but note that it is not used to parse the TeX string
+itself (only LaTeX is supported).  The executables for these external
+dependencies must all be located on your :envvar:`PATH`.
 
 There are a couple of options to mention, which can be changed using
 :doc:`rc settings </tutorials/introductory/customizing>`. Here is an example
@@ -30,7 +25,7 @@ matplotlibrc file::
 
   font.family        : serif
   font.serif         : Times, Palatino, New Century Schoolbook, Bookman, Computer Modern Roman
-  font.sans-serif    : Helvetica, Avant Garde, Computer Modern Sans serif
+  font.sans-serif    : Helvetica, Avant Garde, Computer Modern Sans Serif
   font.cursive       : Zapf Chancery
   font.monospace     : Courier, Computer Modern Typewriter
 
@@ -45,31 +40,52 @@ Computer Modern math fonts. See the PSNFSS_ documentation for more details.
 To use LaTeX and select Helvetica as the default font, without editing
 matplotlibrc use::
 
-  import matplotlib as mpl
+  import matplotlib.pyplot as plt
   plt.rcParams.update({
       "text.usetex": True,
       "font.family": "sans-serif",
       "font.sans-serif": ["Helvetica"]})
-  ## for Palatino and other serif fonts use:
+  # for Palatino and other serif fonts use:
   plt.rcParams.update({
       "text.usetex": True,
       "font.family": "serif",
       "font.serif": ["Palatino"],
   })
+  # It's also possible to use the reduced notation by directly setting font.family:
+  plt.rcParams.update({
+    "text.usetex": True,
+    "font.family": "Helvetica"
+  })
+
+Currently, the supported fonts are:
+
+================= ============================================================
+family            fonts
+================= ============================================================
+``'serif'``         ``'New Century Schoolbook'``, ``'Bookman'``, ``'Times'``,
+                    ``'Palatino'``, ``'Charter'``, ``'Computer Modern Roman'``
+
+``'sans-serif'``  ``'Helvetica'``, ``'Avant Garde'``, ``'Computer Modern
+                  Serif'``
+
+``'cursive'``     ``'Zapf Chancery'``
+
+``'monospace'``   ``'Courier'``, ``'Computer Modern Typewriter'``
+================= ============================================================
 
 Here is the standard example,
-:file:`/gallery/text_labels_and_annotations/tex_demo`:
+:doc:`/gallery/text_labels_and_annotations/tex_demo`:
 
 .. figure:: ../../gallery/text_labels_and_annotations/images/sphx_glr_tex_demo_001.png
    :target: ../../gallery/text_labels_and_annotations/tex_demo.html
    :align: center
-   :scale: 50
-
-   TeX Demo
 
 Note that display math mode (``$$ e=mc^2 $$``) is not supported, but adding the
 command ``\displaystyle``, as in the above demo, will produce the same results.
 
+Non-ASCII characters (e.g. the degree sign in the y-label above) are supported
+to the extent that they are supported by inputenc_.
+
 .. note::
    Certain characters require special escaping in TeX, such as::
 
@@ -78,40 +94,21 @@ command ``\displaystyle``, as in the above demo, will produce the same results.
    Therefore, these characters will behave differently depending on
    :rc:`text.usetex`.
 
-.. _usetex-unicode:
-
-usetex with unicode
-===================
-
-It is also possible to use unicode strings with the LaTeX text manager, here is
-an example taken from :file:`/gallery/text_labels_and_annotations/tex_demo`.
-The axis labels include Unicode text:
-
-.. figure:: ../../gallery/text_labels_and_annotations/images/sphx_glr_tex_demo_001.png
-   :target: ../../gallery/text_labels_and_annotations/tex_demo.html
-   :align: center
-   :scale: 50
-
-   TeX Unicode Demo
-
-.. _usetex-postscript:
-
-Postscript options
+PostScript options
 ==================
 
-In order to produce encapsulated postscript files that can be embedded in a new
-LaTeX document, the default behavior of matplotlib is to distill the output,
-which removes some postscript operators used by LaTeX that are illegal in an
-eps file. This step produces results which may be unacceptable to some users,
-because the text is coarsely rasterized and converted to bitmaps, which are not
-scalable like standard postscript, and the text is not searchable. One
-workaround is to set ``ps.distiller.res`` to a higher value (perhaps 6000)
+In order to produce encapsulated PostScript (EPS) files that can be embedded
+in a new LaTeX document, the default behavior of Matplotlib is to distill the
+output, which removes some PostScript operators used by LaTeX that are illegal
+in an EPS file. This step produces results which may be unacceptable to some
+users, because the text is coarsely rasterized and converted to bitmaps, which
+are not scalable like standard PostScript, and the text is not searchable. One
+workaround is to set :rc:`ps.distiller.res` to a higher value (perhaps 6000)
 in your rc settings, which will produce larger files but may look better and
-scale reasonably. A better workaround, which requires Poppler_ or Xpdf_, can be
-activated by changing the ``ps.usedistiller`` rc setting to ``xpdf``. This
-alternative produces postscript without rasterizing text, so it scales
-properly, can be edited in Adobe Illustrator, and searched text in pdf
-documents.
+scale reasonably. A better workaround, which requires Poppler_ or Xpdf_, can
+be activated by changing :rc:`ps.usedistiller` to ``xpdf``. This alternative
+produces PostScript without rasterizing text, so it scales properly, can be
+edited in Adobe Illustrator, and searched text in pdf documents.
 
 .. _usetex-hangups:
 
@@ -128,13 +125,13 @@ Possible hangups
 
 * On Ubuntu and Gentoo, the base texlive install does not ship with
   the type1cm package. You may need to install some of the extra
-  packages to get all the goodies that come bundled with other latex
+  packages to get all the goodies that come bundled with other LaTeX
   distributions.
 
-* Some progress has been made so matplotlib uses the dvi files
-  directly for text layout. This allows latex to be used for text
+* Some progress has been made so Matplotlib uses the dvi files
+  directly for text layout. This allows LaTeX to be used for text
   layout with the pdf and svg backends, as well as the \*Agg and PS
-  backends. In the future, a latex installation may be the only
+  backends. In the future, a LaTeX installation may be the only
   external dependency.
 
 .. _usetex-troubleshooting:
@@ -152,21 +149,20 @@ Troubleshooting
   that your LaTeX syntax is valid and that you are using raw strings
   if necessary to avoid unintended escape sequences.
 
-* Most problems reported on the mailing list have been cleared up by
-  upgrading Ghostscript_. If possible, please try upgrading to the
-  latest release before reporting problems to the list.
-
-* The ``text.latex.preamble`` rc setting is not officially supported. This
+* :rc:`text.latex.preamble` is not officially supported. This
   option provides lots of flexibility, and lots of ways to cause
   problems. Please disable this option before reporting problems to
   the mailing list.
 
-* If you still need help, please see :ref:`reporting-problems`
+* If you still need help, please see :ref:`reporting-problems`.
 
-.. _LaTeX: http://www.tug.org
 .. _dvipng: http://www.nongnu.org/dvipng/
+.. _dvips: https://tug.org/texinfohtml/dvips.html
 .. _Ghostscript: https://ghostscript.com/
-.. _PSNFSS: http://www.ctan.org/tex-archive/macros/latex/required/psnfss/psnfss2e.pdf
+.. _inputenc: https://ctan.org/pkg/inputenc
+.. _LaTeX: http://www.tug.org
 .. _Poppler: https://poppler.freedesktop.org/
+.. _PSNFSS: http://www.ctan.org/tex-archive/macros/latex/required/psnfss/psnfss2e.pdf
+.. _PSfrag: https://ctan.org/pkg/psfrag
 .. _Xpdf: http://www.xpdfreader.com/
 """
